# -*- coding: utf-8 -*-

FILE = """
BEGIN:VCALENDAR
VERSION:2.0
PRODID:-//Date iCal//NONSGML kigkonsult.se iCalcreator 2.20.2//
METHOD:PUBLISH
X-WR-CALNAME;VALUE=TEXT:UPenn New Student Orientation
BEGIN:VTIMEZONE
TZID:America/New_York
BEGIN:STANDARD
DTSTART:20161106T020000
TZOFFSETFROM:-0400
TZOFFSETTO:-0500
TZNAME:EST
END:STANDARD
BEGIN:DAYLIGHT
DTSTART:20160313T020000
TZOFFSETFROM:-0500
TZOFFSETTO:-0400
RDATE:20170312T020000
TZNAME:EDT
END:DAYLIGHT
END:VTIMEZONE
BEGIN:VEVENT
UID:calendar.678.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160726T132707Z
DESCRIPTION:Mask and Wig Free Show\n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Sunday\, Sep 4 2016 - 8:00 pm\n    
   \nEvent Location: \n  Zellerbach Theatre\, Annenberg Center\n\n      \n 
      \nDescription: \n  \n\nJoin The Mask and Wig Club – America's oldest 
 all-male musical comedy troupe – for our annual Free Show on Sunday\, Sept
 ember 4\, at 8PM in Zellerbach Theatre (located in the Annenberg Center). 
 Free Show is put on exclusively for the freshman class\, and it's a favori
 te tradition to kick off the year. The Cast will make you laugh until you 
 cry\, the Band will melt your face\, the Crew will dazzle you with its sou
 nd and light programming\, and the Business Staff will do what it does bes
 t: sell out the show. Get your tickets quickly and come for a night of com
 edy\, music\, and men in drag. For more information\, please visit here. 
 \n\n      \n\n      \nContact: \n  jgolant@gmail.com for more information.
 \n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160904T200000
DTEND;TZID=America/New_York:20160904T200000
LAST-MODIFIED:20160726T132707Z
LOCATION:3680 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Mask and Wig Free Show
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-05-000000/mask-and-wig
 -free-show
END:VEVENT
BEGIN:VEVENT
UID:calendar.677.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160725T212851Z
DESCRIPTION:WeissLabs Demo Day\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  Tuesday\, Aug 30 2016 - 6:00 pm\n      
 \nEvent Location: \n  Singh Center Glandt Forum and Galleria\n\n      \n  
     \nDescription: \n  \n\nAre you interested in startups\, entrepreneursh
 ip or innovation? Come to WeissLabs Demo Day! Our summer cohort will be pi
 tching their ideas to 5 investors. Our ventures have been hustling all sum
 mer long and are excited to share their ideas with you. There will be a le
 cture followed by a pitch and networking. Applications for our committee a
 nd fall cohort will be available after the event. The event will take plac
 e Tuesday\, August 30th at 6:00 p.m. in the Nanoscience building. \n\n\nWe
 issLabs is committed to catalyzing innovation by engaging students through
  lessons\,￼ community\, and mentorship—leveraging resources across the Uni
 versity of Pennsylvania to foster entrepreneurship.The Weiss Tech House is
  a student- run hub of technological innovation at the University of Penns
 ylvania.  Since 2003\, students with a broad range of interests and skills
  have come here to explore\, collaborate and learn as part of our communit
 y of innovators and entrepreneurs.   We encourage and support students wit
 h everything from development to commercialization\, helping them bring th
 eir biggest ideas to life.\n\n      \n\n      \nContact: \n  info@tech-hou
 se.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160830T180000
DTEND;TZID=America/New_York:20160830T180000
LAST-MODIFIED:20160725T212851Z
LOCATION:3205 Walnut St\, Philadelphia\, PA 19104
SUMMARY:WeissLabs Demo Day
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-30-220000/weisslabs-de
 mo-day
END:VEVENT
BEGIN:VEVENT
UID:calendar.676.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160722T145811Z
DESCRIPTION:Student Activities Fair \n\n      \n              \n\n\nMandato
 ry: No\n      \n      \nDate & Time: \n  Thursday\, Sep 1 2016 - \n5:00 pm
  to 8:00 pm\n      \nEvent Location: \n  Locust Walk and College Green\n\n
       \n      \nDescription: \n  \n\nGet information from over 400 student
  groups and resource centers. \n\n      \n\n      \nContact:  for more inf
 ormation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160901T170000
DTEND;TZID=America/New_York:20160901T200000
LAST-MODIFIED:20160722T145825Z
LOCATION:Locust Walk\, Philadelphia\, PA 19104
SUMMARY:Student Activities Fair
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-01-210000-2016-09-02-0
 00000/student-activities-fair
END:VEVENT
BEGIN:VEVENT
UID:calendar.675.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160721T144054Z
DESCRIPTION:Introduction to the First Generation College Student Program an
 d BBQ\n\n      \n              \n\n\nMandatory: No\n      \n      \nDate &
  Time: \n  Wednesday\, Aug 24 2016 - \n5:00 pm to 6:00 pm\n      \nEvent L
 ocation: \n  Lenape Garden\, Greenfield Intercultural Center (GIC)\n\n    
   \n      \nDescription: \n  \n\nCome meet other First Generation Penn col
 lege students and alums.  Vegetarian\, Gluten free\, Kosher and Halal opti
 ons will be available. RSVP required gic@dolphin.upenn.edu or 215-898-3358
 . For more information\, visit here. \n\n      \n\n      \nContact: \n  gi
 c@dolphin.upenn.edu  for more information.\n\n      \n\n  \n\n\nView large
 r map
DTSTART;TZID=America/New_York:20160824T170000
DTEND;TZID=America/New_York:20160824T180000
LAST-MODIFIED:20160802T143809Z
LOCATION:3708 Chestnut Street Philadelphia\, PA 19104
SUMMARY:Introduction to the First Generation College Student Program and BB
 Q
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-210000-2016-08-24-2
 20000/introduction-first-generation-college-student-program-and
END:VEVENT
BEGIN:VEVENT
UID:calendar.674.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160720T184935Z
DESCRIPTION:Penn Hillel Dessert Reception\n\n      \n              \n\n\nMa
 ndatory: No\n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - 7:
 30 pm\n      \nEvent Location: \n  Penn Hillel at Steinhardt Hall\n\n     
  \n      \nDescription: \n  \n\nEnjoy dessert and meet other new Penn stud
 ents and families. Learn about Jewish life on campus with Penn Hillel staf
 f and student leaders.\n\n      \n\n      \nContact: \n  spodell@pennhille
 l.org for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T193000
DTEND;TZID=America/New_York:20160824T193000
LAST-MODIFIED:20160729T161202Z
LOCATION:215 S 39th St\, Philadelphia\, PA 19104
SUMMARY:Penn Hillel Dessert Reception
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-233000/penn-hillel-
 dessert-reception
END:VEVENT
BEGIN:VEVENT
UID:calendar.658.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160711T133712Z
DESCRIPTION:Named Scholarship Program Social\n\n      \n              \n\n
 \nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 -
  \n2:00 pm to 3:30 pm\n      \nEvent Location: \n  Cohen Auditorium G17 an
 d Schneidman Lobby\n\n      \n      \nDescription: \n  \n\nThe Named Schol
 arship Program welcomes freshmen Named Scholarship recipients. Come snack 
 on water ice and pretzels while getting to know more about the Named Schol
 arship Program and meeting your fellow scholarship recipients. This event 
 is mandatory for first-time Named Scholarship recipients. \n\n      \n\n  
     \nContact: \n  DARFinancialAid@dev.upenn.edu for more information.\n\n
       \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T140000
DTEND;TZID=America/New_York:20160825T153000
LAST-MODIFIED:20160715T131717Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Named Scholarship Program Social
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-180000-2016-08-25-1
 93000/named-scholarship-program-social
END:VEVENT
BEGIN:VEVENT
UID:calendar.657.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160708T182933Z
DESCRIPTION:Immigration Check-In\n\n              \n\n\nMandatory: Yes\n   
    \n      \n      \nDate & Time: \n  \nWednesday\, Aug 24 2016 - 12:00 pm
  to Friday\, Sep 2 2016 - 12:00 pm\n      \nEvent Location: \n  Internatio
 nal Student and Scholar Services\n\n      \n      \nDescription: \n  \n\nA
 ll international and exchange students must check-in with ISSS and bring t
 heir immigration documents for an in-person review. Don't forget to comple
 te the online tutorial and arrival information form! Visit global.upenn.ed
 u/isss/orientation for information about the specific check-in process and
  available times.\n\n      \n\n      \nContact: \n  isss@pobox.upenn.edu f
 or more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T120000
DTEND;TZID=America/New_York:20160902T120000
LAST-MODIFIED:20160804T162156Z
LOCATION:37th & Chestnut Streets
SUMMARY:Immigration Check-In
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-160000-2016-09-02-1
 60000/immigration-check
END:VEVENT
BEGIN:VEVENT
UID:calendar.641.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160630T145132Z
DESCRIPTION:Late Night Events\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  \nFriday\, Aug 26 2016 - 10:00 pm to Sa
 turday\, Aug 27 2016 - 1:00 am\n      \nEvent Location: \n  Various Locati
 ons\n\n      \n      \nDescription: \n  \n\nSponsored by student organizat
 ions. See Late Nights.\n\n      \n\n      \nContact: \n  provost-nso-ai@po
 box.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T220000
DTEND;TZID=America/New_York:20160827T010000
LAST-MODIFIED:20160701T174258Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Late Night Events
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-020000-2016-08-27-0
 50000/late-night-events
END:VEVENT
BEGIN:VEVENT
UID:calendar.443.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160623T180911Z
DESCRIPTION:Getting Around Penn: Guided Tours of Local Businesses\n\n      
 \n              \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Tues
 day\, Aug 23 2016 - \n12:30 pm to 2:30 pm\n      \nEvent Location: \n  Mee
 t at Perry World House\n\n      \n      \nDescription: \n  \n\n \n\n\nSign
  up here to take a trip to bank and phone companies with the ePHINS and iP
 HINS to get settled in Philadelphia.\n\n      \n\n      \nContact: \n  mwe
 iler@upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160823T123000
DTEND;TZID=America/New_York:20160823T143000
LAST-MODIFIED:20160804T214434Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Getting Around Penn: Guided Tours of Local Businesses
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-23-163000-2016-08-23-1
 83000/getting-around-penn-guided-tours-local-businesses
END:VEVENT
BEGIN:VEVENT
UID:calendar.442.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160623T180459Z
DESCRIPTION:International & Exchange Student Welcome Center\n\n      \n    
           \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Tuesday\, 
 Aug 23 2016 - \n9:00 am to 5:00 pm\n      \nEvent Location: \n  Perry Worl
 d House\n\n      \n      \nDescription: \n  \n\nMeet the ePHINS & iPHINS\,
  pick up orientation materials\, and learn how to get started at Penn.\n\n
       \n\n      \nContact: \n  mweiler@upenn.edu for more information.\n\n
       \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160823T090000
DTEND;TZID=America/New_York:20160823T170000
LAST-MODIFIED:20160623T180459Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:International & Exchange Student Welcome Center
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-23-130000-2016-08-23-2
 10000/international-exchange-student-welcome-center
END:VEVENT
BEGIN:VEVENT
UID:calendar.433.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T182552Z
DESCRIPTION:Spanish Placement Exam \n\n      \n              \n\n\nMandator
 y: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n8:00 am t
 o 10:00 am\n      \nEvent Location: \n   DRL A1\n\n      \n      \nDescrip
 tion: \n  \n\nFor more information\, visit here. \n\n      \n\n      \nCon
 tact: \n  vgs@sas.upenn.edu for more information.\n\n      \n\n  \n\n\nVie
 w larger map
DTSTART;TZID=America/New_York:20160829T080000
DTEND;TZID=America/New_York:20160829T100000
LAST-MODIFIED:20160622T182552Z
LOCATION:209 South 33rd Street Philadelphia PA\, 19104
SUMMARY:Spanish Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-120000-2016-08-29-1
 40000/spanish-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.432.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T181410Z
DESCRIPTION:Russian Placement Exam \n\n      \n              \n\n\nMandator
 y: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n4:00 pm t
 o 6:00 pm\n      \nEvent Location: \n  Williams Hall 202 and 205\n\n      
 \n      \nDescription: \n  \n\nFor more information\, visit here. \n\n    
   \n\n      \nContact: \n  slavic@sas.upenn.edu  for more information.\n\n
       \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T160000
DTEND;TZID=America/New_York:20160829T180000
LAST-MODIFIED:20160708T181934Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:Russian Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-200000-2016-08-29-2
 20000/russian-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.430.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T175933Z
DESCRIPTION:Latin Placement Exam\n\n      \n              \n\n\nMandatory: 
 No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n9:00 am to 1
 0:00 am\n      \nEvent Location: \n  Cohen Hall 402\n\n      \n      \nDes
 cription: \n  \n\nFor more information\, visit here. \n\n      \n\n      
 \nContact: \n  jker@sas.upenn.edu for more information.\n\n      \n\n  \n
 \n\nView larger map
DTSTART;TZID=America/New_York:20160829T090000
DTEND;TZID=America/New_York:20160829T100000
LAST-MODIFIED:20160622T175933Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Latin Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-130000-2016-08-29-1
 40000/latin-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.429.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T175304Z
DESCRIPTION:Korean Placement Exam \n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n8:00 am to
  10:00 am\n      \nEvent Location: \n  Williams Hall 202\n\n      \n      
 \nDescription: \n  \n\nOnline Test: Sunday\, August 21 - Sunday\, August 2
 8\n\n\nWriting and Speaking Tests: Monday\, August 29 from 8am-10am in Wil
 liams Hall 202\n\n\nFor more information\, visit here. \n\n      \n\n     
  \nContact: \n  haewcho@sas.upenn.edu for more information.\n\n      \n\n 
  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T080000
DTEND;TZID=America/New_York:20160829T100000
LAST-MODIFIED:20160720T201458Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:Korean Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-120000-2016-08-29-1
 40000/korean-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.428.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T174647Z
DESCRIPTION:Japanese Placement Exam\n\n      \n              \n\n\nMandator
 y: No\n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n8:30 am t
 o 10:00 am\n      \nEvent Location: \n  Williams Hall 1\n\n      \n      
 \nDescription: \n  \n\nFor more information\, visit here. \n\n      \n\n  
     \nContact: \n  ttakami@sas.upenn.edu for more information.\n\n      \n
 \n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T083000
DTEND;TZID=America/New_York:20160826T100000
LAST-MODIFIED:20160622T174647Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:Japanese Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-123000-2016-08-26-1
 40000/japanese-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.427.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T173730Z
DESCRIPTION:Hebrew Placement Exam \n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n4:00 pm to
  6:00 pm\n      \nEvent Location: \n  Cohen Hall 402\n\n      \n      \nDe
 scription: \n  \n\nFor more information\, visit here. \n\n      \n\n      
 \nContact: \n  ronit@sas.upenn.edu for more information.\n\n      \n\n  \n
 \n\nView larger map
DTSTART;TZID=America/New_York:20160829T160000
DTEND;TZID=America/New_York:20160829T180000
LAST-MODIFIED:20160622T173730Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Hebrew Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-200000-2016-08-29-2
 20000/hebrew-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.426.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T173012Z
DESCRIPTION:German Placement Exam \n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n4:00 pm to
  5:30 pm\n      \nEvent Location: \n  Williams Hall 723\n\n      \n      
 \nDescription: \n  \n\nFor more information\, visit here. \n\n      \n\n  
     \nContact: \n  german@ccat.sas.upenn.edu for more information.\n\n    
   \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T160000
DTEND;TZID=America/New_York:20160829T173000
LAST-MODIFIED:20160628T202239Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:German Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-200000-2016-08-29-2
 13000/german-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.425.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T172002Z
DESCRIPTION:German Placement Exam \n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Tuesday\, Aug 30 2016 - \n9:00 am t
 o 10:30 am\n      \nEvent Location: \n  Williams Hall 723\n\n      \n     
  \nDescription: \n  \n\nFor more information\, visit here. \n\n      \n\n 
      \nContact: \n  german@ccat.sas.upenn.edu for more information.\n\n   
    \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160830T090000
DTEND;TZID=America/New_York:20160830T103000
LAST-MODIFIED:20160628T215235Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:German Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-30-130000-2016-08-30-1
 43000/german-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.424.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T171034Z
DESCRIPTION:French and Italian Placement Exams\n\n      \n              \n
 \n\nMandatory: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 -
  \n8:30 am to 10:00 am\n      \nEvent Location: \n  DRL A2\n\n      \n    
   \nDescription: \n  \n\nFor more information\, visit here . \n\n      \n
 \n      \nContact: \n  kgeorgia@sas.upenn.edu for more information.\n\n   
    \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T083000
DTEND;TZID=America/New_York:20160829T100000
LAST-MODIFIED:20160622T171034Z
LOCATION:209 South 33rd Street Philadelphia PA\, 19104
SUMMARY:French and Italian Placement Exams
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-123000-2016-08-29-1
 40000/french-and-italian-placement-exams
END:VEVENT
BEGIN:VEVENT
UID:calendar.423.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T165918Z
DESCRIPTION:Chinese Placement Exam\n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n8:00 am to
  10:00 am\n      \nEvent Location: \n  DRL A2\, A4\, and A8\n\n      \n   
    \nDescription: \n  \n\nFor more information on the Chinese Placement Ex
 am\, visit here. \n\n      \n\n      \nContact: \n  mhchiang@sas.upenn.edu
    for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T080000
DTEND;TZID=America/New_York:20160826T100000
LAST-MODIFIED:20160622T165953Z
LOCATION:209 South 33rd Street Philadelphia PA\, 19104
SUMMARY:Chinese Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-120000-2016-08-26-1
 40000/chinese-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.422.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T165315Z
DESCRIPTION:Arabic Placement Exam\n\n      \n              \n\n\nMandatory:
  No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n4:00 pm to 
 6:00 pm\n      \nEvent Location: \n  Williams Hall 201\n\n      \n      \n
 Description: \n      \n\n      \nContact: \n  emad@sas.upenn.edu  for more
  information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T160000
DTEND;TZID=America/New_York:20160829T180000
LAST-MODIFIED:20160622T165315Z
LOCATION:255 S. 36th Street Philadelphia PA\, 19104
SUMMARY:Arabic Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-200000-2016-08-29-2
 20000/arabic-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.421.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T161044Z
DESCRIPTION:Math 104\, 114\, 115\, 240\, 241 & ALL Postponed (Make-Up) Exam
 s\n\n      \n              \n\n\nMandatory: No\n      \n      \nDate & Tim
 e: \n  Tuesday\, Sep 6 2016 - \n6:00 pm to 8:15 pm\n      \nEvent Location
 : \n  DRL A1\n\n      \n      \nDescription: \n  \n\nFor more information 
 on the Math Placement Exams\, visit here.\n\n      \n\n      \nContact: \n
   ugrad@math.upenn.edu for more information.\n\n      \n\n  \n\n\nView lar
 ger map
DTSTART;TZID=America/New_York:20160906T180000
DTEND;TZID=America/New_York:20160906T201500
LAST-MODIFIED:20160630T165619Z
LOCATION:209 South 33rd Street Philadelphia PA\, 19104
SUMMARY:Math 104\, 114\, 115\, 240\, 241 & ALL Postponed (Make-Up) Exams
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-06-220000-2016-09-07-0
 01500/math-104-114-115-240-241-all-postponed-make-exams
END:VEVENT
BEGIN:VEVENT
UID:calendar.420.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T155931Z
DESCRIPTION:Chemistry 102 Placement Exam \n\n      \n              \n\n\nMa
 ndatory: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n8:0
 0 am to 10:00 am\n      \nEvent Location: \n  Chem 102\n\n      \n      \n
 Description: \n  \n\nFor more information on the Chemistry Placement Exams
 \, visit here. \n\n      \n\n      \nContact: \n  chemugrad@sas.upenn.edu 
 for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T080000
DTEND;TZID=America/New_York:20160829T100000
LAST-MODIFIED:20160708T181848Z
LOCATION:231 South 34th Street Philadelphia PA\, 19104
SUMMARY:Chemistry 102 Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-120000-2016-08-29-1
 40000/chemistry-102-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.419.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T155553Z
DESCRIPTION:Chemistry 101 Placement Exam \n\n      \n              \n\n\nMa
 ndatory: No\n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n8:0
 0 am to 10:00 am\n      \nEvent Location: \n  Chem 102\n\n      \n      \n
 Description: \n  \n\nFor more information on the Chemistry Placement Exams
 \, visit here. \n\n      \n\n      \nContact: \n  chemugrad@sas.upenn.edu 
 for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T080000
DTEND;TZID=America/New_York:20160826T100000
LAST-MODIFIED:20160708T181619Z
LOCATION:231 South 34th Street Philadelphia PA\, 19104
SUMMARY:Chemistry 101 Placement Exam
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-120000-2016-08-26-1
 40000/chemistry-101-placement-exam
END:VEVENT
BEGIN:VEVENT
UID:calendar.417.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T153907Z
DESCRIPTION:Transfer Club Brunch\n\n      \n              \n\n\nMandatory: 
 No\n      \n      \nDate & Time: \n  Sunday\, Sep 4 2016 - \n10:30 am to 1
 2:00 pm\n      \nEvent Location: \n  City Tap House\n\n              \nHos
 t: \n  Transfer Student Organization\n      \n      \nDescription: \n  \n
 \nEnjoy a free brunch after your first week of classes and learn about dif
 ferent undergraduate student groups from older transfers.\n\n      \n\n   
    \nContact: \n  tso.penn@gmail.com for more information.\n\n      \n\n  
 \n\n\nView larger map
DTSTART;TZID=America/New_York:20160904T103000
DTEND;TZID=America/New_York:20160904T120000
LAST-MODIFIED:20160622T153907Z
LOCATION:3925 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Transfer Club Brunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-04-143000-2016-09-04-1
 60000/transfer-club-brunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.416.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T153307Z
DESCRIPTION:Penn's Landing \n\n      \n              \n\n\nMandatory: No\n 
      \n      \nDate & Time: \n  Saturday\, Sep 3 2016 - \n2:00 pm to 5:00 
 pm\n      \nEvent Location: \n  Meet up at Rodin College House \n\n       
        \nHost: \n  Transfer Student Organization\n      \n      \nDescript
 ion: \n  \n\nJoin other transfers and get off campus and into the city to 
 visit Spruce Street Harbor Park.\n\n      \n\n      \nContact: \n  tso.pen
 n@gmail.com for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160903T140000
DTEND;TZID=America/New_York:20160903T170000
LAST-MODIFIED:20160721T145953Z
LOCATION:3901 Locust Walk Philadelphia\, PA 19104
SUMMARY:Penn's Landing
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-03-180000-2016-09-03-2
 10000/penns-landing
END:VEVENT
BEGIN:VEVENT
UID:calendar.415.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T152903Z
DESCRIPTION:A Family Affair: Transfer BBQ Kickback\n\n      \n             
  \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Friday\, Sep 2 2016
  - \n2:00 pm to 4:00 pm\n      \nEvent Location: \n  Hamilton Village\n\n 
              \nHost: \n  Transfer Student Organization\n      \n      \nDe
 scription: \n  \n\nCome out and kick it with the transfers at the annual T
 SO BBQ. It’s an old school family backyard BBQ\, with good vibes and your 
 new on-campus fam! Meet other transfers\, introduce yourself\, get down\, 
 mill around - whatever fits your style. Reunite\, dance\, eat all you can 
 eat\, and enjoy the music.\n\n      \n\n      \nContact: \n  tso.penn@gmai
 l.com for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160902T140000
DTEND;TZID=America/New_York:20160902T160000
LAST-MODIFIED:20160721T150011Z
LOCATION:Hamilton Village Philadelphia\, PA 19104
SUMMARY:A Family Affair: Transfer BBQ Kickback
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-09-02-180000-2016-09-02-2
 00000/family-affair-transfer-bbq-kickback
END:VEVENT
BEGIN:VEVENT
UID:calendar.414.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T152356Z
DESCRIPTION:Tours of Academic Buildings\n\n      \n              \n\n\nMand
 atory: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n2:00 
 pm to 3:30 pm\n      \nEvent Location: \n  The Button\n\n      \n      \nD
 escription: \n  \n\nOrganized tours to help students become familiar with 
 buildings in which their classes take place.\n\n      \n\n      \nContact:
  \n  tso.penn@gmail.com  for more information.\n\n      \n\n  \n\n\nView l
 arger map
DTSTART;TZID=America/New_York:20160829T140000
DTEND;TZID=America/New_York:20160829T153000
LAST-MODIFIED:20160622T185801Z
LOCATION:3420 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Tours of Academic Buildings
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-180000-2016-08-29-1
 93000/tours-academic-buildings
END:VEVENT
BEGIN:VEVENT
UID:calendar.413.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T151908Z
DESCRIPTION:TSO Pancake Night\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  \nSaturday\, Aug 27 2016 - 10:30 pm to 
 Sunday\, Aug 28 2016 - 12:00 am\n      \nEvent Location: \n  Terrace Room\
 , Cohen Hall \n\n              \nHost: \n  Transfer Student Organization 
 \n      \n      \nDescription: \n  \n\nJoin TSO for a night filled with de
 licious homemade pancakes and a selection of tasty toppings. Grab pancakes
 \, meet fellow new transfer students\, and mingle with transfers from past
  years.\n\n      \n\n      \nContact: \n  tso.penn@gmail.com for more info
 rmation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T223000
DTEND;TZID=America/New_York:20160828T000000
LAST-MODIFIED:20160622T151908Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:TSO Pancake Night
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-023000-2016-08-28-0
 40000/tso-pancake-night
END:VEVENT
BEGIN:VEVENT
UID:calendar.412.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T151304Z
DESCRIPTION:Need-to-Know Info Session\n\n              \n\n\nMandatory: Yes
 \n      \n      \n      \nDate & Time: \n  Saturday\, Aug 27 2016 - \n10:0
 0 am to 1:00 pm\n      \nEvent Location: \n  Cohen Auditorium\, Cohen Hall
  \n\n      \n      \nDescription: \n  \n\nTransfers will complete the writ
 ing diagnostic and receive critical information about Penn’s websites\, in
 cluding Penn in Touch. There will also be a writing diagnostic session. Pl
 ease bring your laptops.\n\n      \n\n      \nContact: \n  tso.penn@gmail.
 com for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T100000
DTEND;TZID=America/New_York:20160827T130000
LAST-MODIFIED:20160622T151304Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Need-to-Know Info Session
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-140000-2016-08-27-1
 70000/need-know-info-session
END:VEVENT
BEGIN:VEVENT
UID:calendar.411.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T150401Z
DESCRIPTION:Transfer Advising Session: Wharton\n\n              \n\n\nManda
 tory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 -
  \n11:00 am to 1:00 pm\n      \nEvent Location: \n  G94\, Jon M. Huntsman 
 Hall\n\n              \nHost: \n  The Wharton School\n      \n      \nDesc
 ription: \n  \n\nWharton staff address concerns such as registration\, pri
 or credits\, and requirements.\n\n      \n\n      \nContact: \n  undergrad
 info@wharton.upenn.edu  for more information.\n\n      \n\n  \n\n\nView la
 rger map
DTSTART;TZID=America/New_York:20160826T110000
DTEND;TZID=America/New_York:20160826T130000
LAST-MODIFIED:20160729T161116Z
LOCATION:3730 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Transfer Advising Session: Wharton
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-150000-2016-08-26-1
 70000/transfer-advising-session-wharton
END:VEVENT
BEGIN:VEVENT
UID:calendar.410.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T150105Z
DESCRIPTION:Transfer Advising Session: Engineering\n\n              \n\n\nM
 andatory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 20
 16 - \n11:00 am to 1:00 pm\n      \nEvent Location: \n  Room 321\, Towne B
 uilding\n\n              \nHost: \n  School of Engineering & Applied Scien
 ces \n      \n      \nDescription: \n  \n\nLearn about transferring credit
 s\, registration\, and course selection.\n\n      \n\n      \nContact: \n 
  apo@seas.upenn.edu  for more information.\n\n      \n\n  \n\n\nView large
 r map
DTSTART;TZID=America/New_York:20160826T110000
DTEND;TZID=America/New_York:20160826T130000
LAST-MODIFIED:20160622T150105Z
LOCATION:107 Towne Bldg\, Philadelphia\, PA 19104
SUMMARY:Transfer Advising Session: Engineering
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-150000-2016-08-26-1
 70000/transfer-advising-session-engineering
END:VEVENT
BEGIN:VEVENT
UID:calendar.409.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T145558Z
DESCRIPTION:Transfer Advising Session: Nursing\n\n              \n\n\nManda
 tory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 -
  \n11:00 am to 12:30 pm\n      \nEvent Location: \n  Room 207\, Claire M. 
 Fagin Hall\n\n              \nHost: \n  School of Nursing \n      \n      
 \nDescription: \n  \n\nHave your transfer credit and plan of study questio
 ns answered during this advising session with Penn Nursing.\n\n\nMandatory
 : Yes\n\n      \n\n      \nContact: \n  advisor@nursing.upenn.edu  for mor
 e information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T110000
DTEND;TZID=America/New_York:20160826T123000
LAST-MODIFIED:20160729T152811Z
LOCATION:418 Curie Boulevard\, Philadelphia\, PA 19104
SUMMARY:Transfer Advising Session: Nursing
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-150000-2016-08-26-1
 63000/transfer-advising-session-nursing
END:VEVENT
BEGIN:VEVENT
UID:calendar.408.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160622T145201Z
DESCRIPTION:Transfer Advising Session: The College\n\n              \n\n\nM
 andatory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 20
 16 - \n10:00 am to 12:00 pm\n      \nEvent Location: \n  Cohen Auditorium\
 , Cohen Hall \n\n              \nHost: \n  College of Arts and Sciences\n 
      \n      \nDescription: \n  \n\nGet instructions on the College’s proc
 edures\, policies\, requirements\, and curricular options.\n\n      \n\n  
     \nContact: \n  college@sas.upenn.edu for more information.\n\n      \n
 \n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T100000
DTEND;TZID=America/New_York:20160826T120000
LAST-MODIFIED:20160711T152638Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Transfer Advising Session: The College
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-140000-2016-08-26-1
 60000/transfer-advising-session-college
END:VEVENT
BEGIN:VEVENT
UID:calendar.406.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T170447Z
DESCRIPTION:PHINS Guided Tour for Students\n\n      \n              \n\n\nM
 andatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n
 1:00 pm to 2:30 pm\n      \nEvent Location: \n  Wynn Commons\n\n      \n  
     \nDescription: \n  \n\nThe Transfer PHINS will lead students on a tour
  of important buildings on campus.\n\n      \n\n      \nContact: \n  tso.p
 enn@gmail.com for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T130000
DTEND;TZID=America/New_York:20160825T143000
LAST-MODIFIED:20160621T170447Z
LOCATION:Perelman Quadrangle\, Philadelphia\, PA 19104
SUMMARY:PHINS Guided Tour for Students
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-170000-2016-08-25-1
 83000/phins-guided-tour-students
END:VEVENT
BEGIN:VEVENT
UID:calendar.405.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T163718Z
DESCRIPTION:Transfer Welcome Session\n\n              \n\n\nMandatory: Yes
 \n      \n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n12:0
 0 pm to 1:00 pm\n      \nEvent Location: \n  Cohen Auditorium\, Cohen Hall
  \n\n      \n      \nDescription: \n  \n\nAn overview of transfer orientat
 ion and a presentation from Public Safety.\n\n      \n\n      \nContact: 
 \n   tso.penn@gmail.com for more information.\n\n      \n\n  \n\n\nView la
 rger map
DTSTART;TZID=America/New_York:20160825T120000
DTEND;TZID=America/New_York:20160825T130000
LAST-MODIFIED:20160622T144606Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Transfer Welcome Session
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-160000-2016-08-25-1
 70000/transfer-welcome-session
END:VEVENT
BEGIN:VEVENT
UID:calendar.404.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T162553Z
DESCRIPTION:Transfer Student Welcome Center\n\n      \n              \n\n\n
 Mandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - 
 \n9:00 am to 5:00 pm\n      \nEvent Location: \n  Houston Hall\, 1st Floor
  Lobby\n\n      \n      \nDescription: \n  \n\nMeet the PHINS\, pick up or
 ientation materials\, sign up for various events\, and join your class lis
 tserv.\n\n      \n\n      \nContact: \n   tso.penn@gmail.com for more info
 rmation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T090000
DTEND;TZID=America/New_York:20160825T170000
LAST-MODIFIED:20160621T162553Z
LOCATION:3417 Spruce St Philadelphia\, PA 19104
SUMMARY:Transfer Student Welcome Center
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-130000-2016-08-25-2
 10000/transfer-student-welcome-center
END:VEVENT
BEGIN:VEVENT
UID:calendar.403.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T161949Z
DESCRIPTION:Small Group Dinners\n\n      \n              \n\n\nMandatory: N
 o\n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - \n6:00 pm to
  8:00 pm\n      \nEvent Location: \n  Meet at the Button \n\n      \n     
  \nDescription: \n  \n\nA wonderful introduction to local restaurants. Cha
 t with friends in a relaxing\, exciting restaurant. Take your pick among v
 arious local cuisines around University City!\n\n      \n\n      \nContact
 : \n   tso.penn@gmail.com for more information.\n\n      \n\n  \n\n\nView 
 larger map
DTSTART;TZID=America/New_York:20160824T180000
DTEND;TZID=America/New_York:20160824T200000
LAST-MODIFIED:20160721T150118Z
LOCATION:3417 Spruce St Philadelphia\, PA 19104
SUMMARY:Small Group Dinners
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-220000-2016-08-25-0
 00000/small-group-dinners
END:VEVENT
BEGIN:VEVENT
UID:calendar.402.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T161116Z
DESCRIPTION:Transfer Student Welcome Center \n\n      \n              \n\n
 \nMandatory: No\n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 
 - \n9:00 am to 5:00 pm\n      \nEvent Location: \n  1st Floor Lobby\, Hous
 ton Hall\n\n      \n      \nDescription: \n  \n\nMeet the PHINS\, pick up 
 orientation materials\, sign up for various events\, and join your class l
 istserv.\n\n      \n\n      \nContact: \n  tso.penn@gmail.com for more inf
 ormation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T090000
DTEND;TZID=America/New_York:20160824T170000
LAST-MODIFIED:20160728T204504Z
LOCATION:3417 Spruce St Philadelphia\, PA 19104
SUMMARY:Transfer Student Welcome Center
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-130000-2016-08-24-2
 10000/transfer-student-welcome-center
END:VEVENT
BEGIN:VEVENT
UID:calendar.400.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T154504Z
DESCRIPTION:Wharton Class of 2020 “Tuesday Takeover”\n\n      \n           
    \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Monday\, Aug 29 2
 016 - \n2:00 pm to 3:00 pm\n      \nEvent Location: \n  Koo Plaza & Café (
 2nd floor)\, Jon M. Huntsman Hall \n\n              \nHost: \n  The Wharto
 n School\n      \n      \nDescription: \n  \n\nCelebrate the end of your f
 irst day at Wharton with your classmates.  Enjoy interactive games\, great
  food\, giveaways\, and network with your classmates\, student leaders\, a
 nd staff!\n\n      \n\n      \nContact: \n   undergradinfo@wharton.upenn.e
 du for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T140000
DTEND;TZID=America/New_York:20160829T150000
LAST-MODIFIED:20160621T154504Z
LOCATION:3730 Walnut St Philadelphia\, PA 19104
SUMMARY:Wharton Class of 2020 “Tuesday Takeover”
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-180000-2016-08-29-1
 90000/wharton-class-2020-%E2%80%9Ctuesday-takeover%E2%80%9D
END:VEVENT
BEGIN:VEVENT
UID:calendar.399.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T153929Z
DESCRIPTION:Cohort Lunch\n\n              \n\n\nMandatory: Yes\n      \n   
    \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n12:30 pm to 2:00 pm
 \n      \nEvent Location: \n  Same as “Meet Your Cohort” classrooms \n\n  
             \nHost: \n  The Wharton School\n      \n      \nDescription: 
 \n  \n\nHave lunch\, meet your cohort\, and learn all about the cohort pro
 gram!  \n\n      \n\n      \nContact: \n   undergradinfo@wharton.upenn.edu
  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T123000
DTEND;TZID=America/New_York:20160829T140000
LAST-MODIFIED:20160621T153929Z
LOCATION:3730 Walnut St Philadelphia\, PA 19104
SUMMARY:Cohort Lunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-163000-2016-08-29-1
 80000/cohort-lunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.398.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T153522Z
DESCRIPTION:Academic and Student Life Panels and Wharton Tour\n\n          
     \n\n\nMandatory: Yes\n      \n      \n      \nDate & Time: \n  Monday\
 , Aug 29 2016 - \n11:00 am to 12:30 pm\n      \nEvent Location: \n  Variou
 s Locations\, Jon M. Huntsman Hall\n\n              \nHost: \n  The Wharto
 n School\n      \n      \nDescription: \n  \n\nJoin Academic Advisors\, St
 udent Life staff\, Peer Advising Fellows\, and Cohort Leaders for this int
 eractive program about academic and co-curricular life at Wharton. \n\n   
    \n\n      \nContact: \n  undergradinfo@wharton.upenn.edu  for more info
 rmation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T110000
DTEND;TZID=America/New_York:20160829T123000
LAST-MODIFIED:20160621T153522Z
LOCATION:3730 Walnut St Philadelphia\, PA 19104
SUMMARY:Academic and Student Life Panels and Wharton Tour
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-150000-2016-08-29-1
 63000/academic-and-student-life-panels-and-wharton-tour
END:VEVENT
BEGIN:VEVENT
UID:calendar.397.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T153133Z
DESCRIPTION:Dean’s Welcome\n\n              \n\n\nMandatory: Yes\n      \n 
      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n10:30 am to 11:00
  am\n      \nEvent Location: \n  Baker Forum\, Jon M. Huntsman Hall\n\n   
            \nHost: \n  The Wharton School \n      \n      \nDescription: 
 \n  \n\nDean Geoffrey Garrett\, Vice Dean Lori Rosenkopf\, Undergraduate D
 ivision administrators\, and student leaders will formally welcome the Cla
 ss of 2020.\n\n      \n\n      \nContact: \n  undergradinfo@wharton.upenn.
 edu  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T103000
DTEND;TZID=America/New_York:20160829T110000
LAST-MODIFIED:20160621T153133Z
LOCATION:3730 Walnut St Philadelphia\, PA 19104
SUMMARY:Dean’s Welcome
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-143000-2016-08-29-1
 50000/dean%E2%80%99s-welcome
END:VEVENT
BEGIN:VEVENT
UID:calendar.396.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T152323Z
DESCRIPTION:Meet Your Cohort\n\n              \n\n\nMandatory: Yes\n      
 \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n10:00 am to 10
 :30 am\n      \nEvent Location: \n  Jon M. Huntsman Hall\n\n              
 \nHost: \n  The Wharton School\n      \n      \nDescription: \n  \n\nStude
 nts meet with their cohort and Cohort Leaders.\nDinar  \n    Room TBD\nDol
 lar\n    Room TBD\nEuro\n    Room TBD\nPeso\n    Room TBD\nRand\n    Room 
 TBD\nRupee\n    Room TBD\nShekel \n    Room TBD\nYen \n    Room TBD\nYuan 
  \n    Room TBD\n\n\n \n\n      \n\n      \nContact: \n  undergradinfo@wha
 rton.upenn.edu  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T100000
DTEND;TZID=America/New_York:20160829T103000
LAST-MODIFIED:20160621T153224Z
LOCATION:3730 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Meet Your Cohort
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-140000-2016-08-29-1
 43000/meet-your-cohort
END:VEVENT
BEGIN:VEVENT
UID:calendar.395.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T150907Z
DESCRIPTION:Academic Advising\n\n              \n\n\nMandatory: Yes\n      
 \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n1:30 pm to 5:0
 0 pm\n      \nEvent Location: \n  Various Locations\n\n      \n      \nDes
 cription: \n  \n\nStudents will meet with their Academic Advisor in their 
 respective school at Penn over the course of the afternoon. Details will b
 e provided during the Academic Advising & Integrity session.\n\n      \n\n
       \nContact: \n  mweiler@upenn.edu  for more information.
DTSTART;TZID=America/New_York:20160826T133000
DTEND;TZID=America/New_York:20160826T170000
LAST-MODIFIED:20160630T185426Z
SUMMARY:Academic Advising
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-173000-2016-08-26-2
 10000/academic-advising
END:VEVENT
BEGIN:VEVENT
UID:calendar.394.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T150329Z
DESCRIPTION:Academic Resources and Integrity\n\n              \n\n\nMandato
 ry: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - 
 \n10:00 am to 11:30 am\n      \nEvent Location: \n  Perry World House Audi
 torium\n\n      \n      \nDescription: \n  \n\nStudents will learn about a
 cademic support resources at Penn and hear important information including
  rules regarding plagiarism and cheating at Penn.\n\n      \n\n      \nCon
 tact: \n  mweiler@upenn.edu for more information.\n\n      \n\n  \n\n\nVie
 w larger map
DTSTART;TZID=America/New_York:20160826T100000
DTEND;TZID=America/New_York:20160826T113000
LAST-MODIFIED:20160630T185012Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Academic Resources and Integrity
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-140000-2016-08-26-1
 53000/academic-resources-and-integrity
END:VEVENT
BEGIN:VEVENT
UID:calendar.392.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160621T145348Z
DESCRIPTION:Resource Center Tour\n\n              \n\n\nMandatory: Yes\n   
    \n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n2:30 pm t
 o 4:00 pm\n      \nEvent Location: \n  Leave from Perry World House\n\n   
    \n      \nDescription: \n  \n\nExplore the campus with the ePHINs and d
 iscover its many resources.\n\n      \n\n      \nContact: \n  mweiler@upen
 n.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T143000
DTEND;TZID=America/New_York:20160825T160000
LAST-MODIFIED:20160630T184551Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Resource Center Tour
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-183000-2016-08-25-2
 00000/resource-center-tour
END:VEVENT
BEGIN:VEVENT
UID:calendar.371.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T204931Z
DESCRIPTION:Public Safety and Interpersonal Violence\n\n              \n\n
 \nMandatory: Yes\n      \n      \n      \nDate & Time: \n  Thursday\, Aug 
 25 2016 - \n1:30 pm to 2:30 pm\n      \nEvent Location: \n  Perry World Ho
 use Auditorium\n\n      \n      \nDescription: \n  \n\nExchange students w
 ill be addressed by representatives from the Penn Women’s Center and the D
 ivision of Public Safety regarding healthy sexuality and sexual assault re
 sponse and support.\n\n      \n\n      \nContact: \n  mweiler@upenn.edu fo
 r more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T133000
DTEND;TZID=America/New_York:20160825T143000
LAST-MODIFIED:20160708T181341Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Public Safety and Interpersonal Violence
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-173000-2016-08-25-1
 83000/public-safety-and-interpersonal-violence
END:VEVENT
BEGIN:VEVENT
UID:calendar.370.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T204726Z
DESCRIPTION:ePHINS Lunch\n\n              \n\n\nMandatory: Yes\n      \n   
    \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n12:00 pm to 1:30 
 pm\n      \nEvent Location: \n   Leave from Perry World House \n\n      \n
       \nDescription: \n  \n\nEnjoy lunch with the ePHINS and learn more ab
 out their experiences at Penn.\n\n      \n\n      \nContact: \n  mweiler@u
 penn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T120000
DTEND;TZID=America/New_York:20160825T133000
LAST-MODIFIED:20160630T184337Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:ePHINS Lunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-160000-2016-08-25-1
 73000/ephins-lunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.369.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T204510Z
DESCRIPTION:Target Store Trip\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n12:30 pm to 
 3:30 pm\n      \nEvent Location: \n  Meet the iPHINS at the corner of 34th
  Street and Walnut Street\n\n      \n      \nDescription: \n  \n\nSign up 
 here to take a bus to a Target store and buy necessities for your room.\n
 \n      \n\n      \nContact: \n  ryanv@upenn.edu for more information.\n\n
       \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T123000
DTEND;TZID=America/New_York:20160825T153000
LAST-MODIFIED:20160804T214028Z
LOCATION:34th Street and Walnut Street
SUMMARY:Target Store Trip
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-163000-2016-08-25-1
 93000/target-store-trip
END:VEVENT
BEGIN:VEVENT
UID:calendar.359.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T193646Z
DESCRIPTION:International Student Welcome Session\n\n              \n\n\nMa
 ndatory: Yes\n      \n      \n      \nDate & Time: \n  Thursday\, Aug 25 2
 016 - \n10:30 am to 12:00 pm\n      \nEvent Location: \n  Bottom Floor\, M
 eyerson Hall\n\n      \n      \nDescription: \n  \n\nThe Assembly of Inter
 national Students and the iPHINS give an interactive introduction to life 
 at Penn and Philly\; basic necessities such as phones\, banking\, shopping
 \, and entertainment will be covered. Dr. Rudie Altamirano\, Director of I
 SSS\, provides a welcome presentation on the life of an international stud
 ent in the U.S.\n\n      \n\n      \nContact: \n  ahaan@sas.upenn.edu for 
 more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T103000
DTEND;TZID=America/New_York:20160825T120000
LAST-MODIFIED:20160712T163008Z
LOCATION:210 S 34th St\, Philadelphia\, PA 19104
SUMMARY:International Student Welcome Session
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-143000-2016-08-25-1
 60000/international-student-welcome-session
END:VEVENT
BEGIN:VEVENT
UID:calendar.357.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T193440Z
DESCRIPTION:Exchange Student Welcome Session\n\n              \n\n\nMandato
 ry: Yes\n      \n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 -
  \n10:30 am to 12:00 pm\n      \nEvent Location: \n  Perry World House Aud
 itorium\n\n      \n      \nDescription: \n  \n\nWelcoming session presente
 d by Penn Abroad to give an interactive introduction to life at Penn and P
 hilly and provide information about your exchange program.\n\n      \n\n  
     \nContact: \n  mweiler@upenn.edu for more information.\n\n      \n\n  
 \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T103000
DTEND;TZID=America/New_York:20160825T120000
LAST-MODIFIED:20160630T184241Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Exchange Student Welcome Session
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-143000-2016-08-25-1
 60000/exchange-student-welcome-session
END:VEVENT
BEGIN:VEVENT
UID:calendar.347.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T181316Z
DESCRIPTION:Flash Talks - Adjusting to Your New Home\n\n      \n           
    \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25
  2016 - \n9:00 am to 10:30 am\n      \nEvent Location: \n  Bottom Floor\, 
 Meyerson Hall\n\n      \n      \nDescription: \n  \n\nInternational Studen
 t and Scholar Services\, Counseling and Psychological Services and Weingar
 ten Learning Resources Center\, host a series of brief and helpful present
 ations that will help you succeed at Penn. Light breakfast snacks provided
 . \n\n      \n\n      \nContact: \n  mweiler@upenn.edu for more informatio
 n.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T090000
DTEND;TZID=America/New_York:20160825T103000
LAST-MODIFIED:20160712T170535Z
LOCATION:210 S 34th St\, Philadelphia\, PA 19104
SUMMARY:Flash Talks - Adjusting to Your New Home
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-130000-2016-08-25-1
 43000/flash-talks-adjusting-your-new-home
END:VEVENT
BEGIN:VEVENT
UID:calendar.346.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T180800Z
DESCRIPTION:From Philly to Vegas: Casino Night\n\n      \n              \n
 \n\nMandatory: No\n      \n      \nDate & Time: \n  \nWednesday\, Aug 24 2
 016 - 10:00 pm to Thursday\, Aug 25 2016 - 12:00 am\n      \nEvent Locatio
 n: \n  Hall of Flags\, Houston Hall \n\n      \n      \nDescription: \n  
 \n\nA night of snacks and fun mocktails where students will be able to eat
 \, drink\, mingle\, and play classic games in an exciting\, casino atmosph
 ere.\n\n      \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for 
 more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T220000
DTEND;TZID=America/New_York:20160825T000000
LAST-MODIFIED:20160720T194441Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:From Philly to Vegas: Casino Night
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-020000-2016-08-25-0
 40000/philly-vegas-casino-night
END:VEVENT
BEGIN:VEVENT
UID:calendar.345.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T175734Z
DESCRIPTION:Taste of Philly Small Group Dinners\n\n              \n\n\nMand
 atory: Yes\n      \n      \n      \nDate & Time: \n  Wednesday\, Aug 24 20
 16 - \n6:00 pm to 8:00 pm\n      \nEvent Location: \n  Meet at the Button 
 \n\n      \n      \nDescription: \n  \n\nJoin Penn students and other exch
 ange students for dinner at local restaurants near Penn’s campus. Please b
 ring approximately $15-$20 for dinner.\n\n      \n\n      \nContact: \n  m
 weiler@upenn.edu for more information.\n\n      \n\n  \n\n\nView larger ma
 p
DTSTART;TZID=America/New_York:20160824T180000
DTEND;TZID=America/New_York:20160824T200000
LAST-MODIFIED:20160630T183126Z
LOCATION:3420 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Taste of Philly Small Group Dinners
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-220000-2016-08-25-0
 00000/taste-philly-small-group-dinners
END:VEVENT
BEGIN:VEVENT
UID:calendar.344.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T175449Z
DESCRIPTION:Welcome Dinner for New International Students and Families\n\n 
      \n              \n\n\nMandatory: No\n      \n      \nDate & Time: \n 
  Wednesday\, Aug 24 2016 - \n6:00 pm to 8:00 pm\n      \nEvent Location: 
 \n  Tent on Wynn Commons\n\n      \n      \nDescription: \n  \n\nPenn Glob
 al and Penn Parents welcome new international undergraduate students and t
 heir families to Penn. Meet other new Penn families from across the globe 
 and enjoy a delicious meal! (By invitation only. Registration required. Re
 gistered students and families may pick up tickets at Perry World House at
  3803 Locust Walk on August 23-24 from 10:00am-3:00pm)\n\n      \n\n      
 \nContact: \n  sadamson@upenn.edu for more information.\n\n      \n\n  \n
 \n\nView larger map
DTSTART;TZID=America/New_York:20160824T180000
DTEND;TZID=America/New_York:20160824T200000
LAST-MODIFIED:20160712T194926Z
LOCATION:Perelman Quadrangle\, Philadelphia\, PA 19104
SUMMARY:Welcome Dinner for New International Students and Families
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-220000-2016-08-25-0
 00000/welcome-dinner-new-international-students-and-families
END:VEVENT
BEGIN:VEVENT
UID:calendar.343.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T172435Z
DESCRIPTION:Social Mixer for International Students Traveling Alone\n\n    
   \n              \n\n\nMandatory: No\n      \n      \nDate & Time: \n  We
 dnesday\, Aug 24 2016 - \n5:00 pm to 5:45 pm\n      \nEvent Location: \n  
 Ben Franklin Room\, Houston Hall \n\n      \n      \nDescription: \n  \n\n
 Flying solo? Join us for a Social Mixer to meet other new international un
 dergraduate students who traveled to Penn on their own and then walk to th
 e Welcome Dinner together!  (Note: Separate registration for the Welcome D
 inner is required and by invitation only. Please see event for additional 
 details.) \n\n      \n\n      \nContact: \n  ryanv@upenn.edu for more info
 rmation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T170000
DTEND;TZID=America/New_York:20160824T174500
LAST-MODIFIED:20160715T151505Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Social Mixer for International Students Traveling Alone
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-210000-2016-08-24-2
 14500/social-mixer-international-students-traveling-alone
END:VEVENT
BEGIN:VEVENT
UID:calendar.342.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T170353Z
DESCRIPTION:ISO Water Cup\n\n      \n              \n\n\nMandatory: No\n   
    \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - \n2:30 pm to 4:00 
 pm\n      \nEvent Location: \n  Meet at the Button (in front of Van Pelt)
 \n\n      \n      \nDescription: \n  \n\nCome cool down with your fellow i
 nternational students at the ISO water fight! You will get wet!\n\n      
 \n\n      \nContact: \n  ahaan@sas.upenn.edu for more information.\n\n    
   \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T143000
DTEND;TZID=America/New_York:20160824T160000
LAST-MODIFIED:20160712T163014Z
LOCATION:3420 Walnut St\, Philadelphia\, PA 19104
SUMMARY:ISO Water Cup
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-183000-2016-08-24-2
 00000/iso-water-cup
END:VEVENT
BEGIN:VEVENT
UID:calendar.341.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T165300Z
DESCRIPTION:Getting Around Penn: Guided Tours of Local Businesses\n\n      
 \n              \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Wedn
 esday\, Aug 24 2016 - \n12:30 pm to 2:30 pm\n      \nEvent Location: \n  M
 eet at Perry World House\n\n      \n      \nDescription: \n  \n\nSign up h
 ere to take a trip to bank and phone companies with the ePHINS and iPHINS 
 to get settled in Philadelphia.\n\n      \n\n      \nContact: \n  mweiler@
 upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T123000
DTEND;TZID=America/New_York:20160824T143000
LAST-MODIFIED:20160804T214152Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:Getting Around Penn: Guided Tours of Local Businesses
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-163000-2016-08-24-1
 83000/getting-around-penn-guided-tours-local-businesses
END:VEVENT
BEGIN:VEVENT
UID:calendar.336.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160620T154801Z
DESCRIPTION:International & Exchange Student Welcome Center\n\n      \n    
           \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Wednesday\
 , Aug 24 2016 - \n9:00 am to 5:00 pm\n      \nEvent Location: \n  Perry Wo
 rld House\n\n      \n      \nDescription: \n  \n\nMeet the ePHINS & iPHINS
 \, pick up orientation materials\, and learn how to get started at Penn.\n
 \n      \n\n      \nContact: \n  mweiler@upenn.edu for more information.\n
 \n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T090000
DTEND;TZID=America/New_York:20160824T170000
LAST-MODIFIED:20160621T204403Z
LOCATION:3803 Locust Wlk. Philadelphia PA\, 19104
SUMMARY:International & Exchange Student Welcome Center
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-130000-2016-08-24-2
 10000/international-exchange-student-welcome-center
END:VEVENT
BEGIN:VEVENT
UID:calendar.317.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T165352Z
DESCRIPTION:Info to Know…Before You Go: Penn Parent Orientation Panel & Far
 ewell Proud Penn Parents\n\n      \n              \n\n\nMandatory: No\n   
    \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n4:45 pm to 6:00 p
 m\n      \nEvent Location: \n  Irvine Auditorium and Café 58\, Irvine\n\n 
      \n      \nDescription: \n  \n\nPenn experts will provide an overview 
 of relevant issues including College Houses\, academics\, safety\, and fin
 ances. Staff will be on hand to answer questions. This marks the official 
 conclusion of New Parent and Family Orientation. For more information\, an
 d to register for NPFO\, please visit this link.\n\n      \n\n      \nCont
 act: \n  ppparent@ben.dev.upenn.edu for more information.\n\n      \n\n  
 \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T164500
DTEND;TZID=America/New_York:20160825T180000
LAST-MODIFIED:20160725T150911Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Info to Know…Before You Go: Penn Parent Orientation Panel & Farewel
 l Proud Penn Parents
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-204500-2016-08-25-2
 20000/info-know%E2%80%A6-you-go-penn-parent-orientation-panel-farewell
END:VEVENT
BEGIN:VEVENT
UID:calendar.316.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T165111Z
DESCRIPTION:New Penn Parent Session B\n\n      \n              \n\n\nMandat
 ory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n2:00 
 pm to 3:00 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n         
      \nHost: \n  Penn Parents \n      \n      \nDescription: \n  \n\nParen
 ts are invited to this session to gain insight about the transition to Pen
 n and how to stay connected from afar. Sessions A and B present identical 
 information. For more information\, and to register for New Parent and Fam
 ily Orientation (NPFO)\, please visit this link.\n\n      \n\n      \nCont
 act: \n  ppparent@ben.dev.upenn.edu for more information.\n\n      \n\n  
 \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T140000
DTEND;TZID=America/New_York:20160825T150000
LAST-MODIFIED:20160725T150435Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:New Penn Parent Session B
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-180000-2016-08-25-1
 90000/new-penn-parent-session-b
END:VEVENT
BEGIN:VEVENT
UID:calendar.315.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T164900Z
DESCRIPTION:Campus Tours\n\n      \n              \n\n\nMandatory: No\n    
   \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n11:00 am to 1:00 p
 m\n      \nEvent Location: \n  Depart from Admissions Office in College Ha
 ll\n\n      \n      \nDescription: \n  \n\nTours\, led by current Penn stu
 dents\, are the best source of information about Penn’s history and tradit
 ions\, academic experience\, and residential life. For more information on
  this event\, and to register for New Parent and Family Orientation (NPFO)
 \, please visit this link.\n\n      \n\n      \nContact: \n  nso@exchange.
 upenn.edu  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T110000
DTEND;TZID=America/New_York:20160825T130000
LAST-MODIFIED:20160804T181731Z
LOCATION:1 College Hall\, Philadelphia\, PA 19104
SUMMARY:Campus Tours
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-150000-2016-08-25-1
 70000/campus-tours
END:VEVENT
BEGIN:VEVENT
UID:calendar.314.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T164148Z
DESCRIPTION:Penn Family Welcome Picnic\n\n      \n              \n\n\nManda
 tory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n11:0
 0 am to 1:00 pm\n      \nEvent Location: \n  Tent on Wynn Commons\n\n     
  \n      \nDescription: \n  \n\nEnjoy a picnic to welcome Penn families.\n
 \n      \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more i
 nformation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T110000
DTEND;TZID=America/New_York:20160825T130000
LAST-MODIFIED:20160701T171810Z
LOCATION:Perelman Quadrangle\, Philadelphia\, PA 19104
SUMMARY:Penn Family Welcome Picnic
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-150000-2016-08-25-1
 70000/penn-family-welcome-picnic
END:VEVENT
BEGIN:VEVENT
UID:calendar.313.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T163041Z
DESCRIPTION:New Penn Parent Session A\n\n      \n              \n\n\nMandat
 ory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n11:00
  am to 12:00 pm\n      \nEvent Location: \n  Irvine Auditorium\n\n        
       \nHost: \n  Penn Parents \n      \n      \nDescription: \n  \n\nPare
 nts are invited to this session to gain insight about the transition to Pe
 nn and how to stay connected from afar. Sessions A and B present identical
  information. For more information on this event\, and to register for New
  Parent and Family Orientation (NPFO)\, please visit this link.\n\n      
 \n\n      \nContact: \n  ppparent@ben.dev.upenn.edu for more information.
 \n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T110000
DTEND;TZID=America/New_York:20160825T120000
LAST-MODIFIED:20160725T150457Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:New Penn Parent Session A
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-150000-2016-08-25-1
 60000/new-penn-parent-session
END:VEVENT
BEGIN:VEVENT
UID:calendar.312.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T162817Z
DESCRIPTION:Penn Parents Info Station\n\n      \n              \n\n\nMandat
 ory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n9:00 
 am to 2:30 pm\n      \nEvent Location: \n  Reading Room\, Houston Hall\n\n
               \nHost: \n  Penn Parents \n      \n      \nDescription: \n  
 \n\nCheck in with the Penn Parents team to begin orientation. For more inf
 ormation on this event\, and to register for New Parent and Family Orienta
 tion (NPFO)\, please visit this link.\n\n      \n\n      \nContact: \n  pp
 parent@ben.dev.upenn.edu for more information.\n\n      \n\n  \n\n\nView l
 arger map
DTSTART;TZID=America/New_York:20160825T090000
DTEND;TZID=America/New_York:20160825T143000
LAST-MODIFIED:20160725T150017Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Penn Parents Info Station
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-130000-2016-08-25-1
 83000/penn-parents-info-station
END:VEVENT
BEGIN:VEVENT
UID:calendar.311.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T162423Z
DESCRIPTION:Penn Parents Info Station\n\n      \n              \n\n\nMandat
 ory: No\n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - \n9:00
  am to 4:30 pm\n      \nEvent Location: \n  Reading Room\, Houston Hall\n
 \n      \n      \nDescription: \n  \n\nCheck in with the Penn Parents team
  to begin orientation. For more information on this event\, and to registe
 r for New Parent and Family Orientation (NPFO)\, please visit this link.\n
 \n      \n\n      \nContact: \n  ppparent@ben.dev.upenn.edu for more infor
 mation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T090000
DTEND;TZID=America/New_York:20160824T163000
LAST-MODIFIED:20160725T150034Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Penn Parents Info Station
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-130000-2016-08-24-2
 03000/penn-parents-info-station
END:VEVENT
BEGIN:VEVENT
UID:calendar.310.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T161533Z
DESCRIPTION:Faculty Advising Meetings\n\n              \n\n\nMandatory: Yes
 \n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n12:00 
 pm to 4:00 pm\n      \nEvent Location: \n  Faculty offices. Check your PUR
 L for exact location.\n\n              \nHost: \n  School of Engineering &
  Applied Sciences \n      \n      \nDescription: \n  \n\nFaculty Advisors 
 will be assigned to you at the beginning of NSO. Meet with your Faculty Ad
 visor at the designated meeting dates and times. An updated list will be o
 n the PURL and with your OPA!\n\n      \n\n      \nContact: \n  apo@seas.u
 penn.edu  for more information.
DTSTART;TZID=America/New_York:20160829T120000
DTEND;TZID=America/New_York:20160829T160000
LAST-MODIFIED:20160620T153244Z
SUMMARY:Faculty Advising Meetings
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-160000-2016-08-29-2
 00000/faculty-advising-meetings
END:VEVENT
BEGIN:VEVENT
UID:calendar.309.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T161313Z
DESCRIPTION:Lunch with OPA!s and Departmental Faculty\n\n              \n\n
 \nMandatory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29
  2016 - \n12:00 pm to 1:00 pm\n      \nEvent Location: \n  Various Locatio
 ns\n\n              \nHost: \n  School of Engineering & Applied Sciences 
 \n      \n      \nDescription: \n  \n\nGet to know the faculty and student
 s in your department\, major\, and program over boxed lunches.\n\n      \n
 \n      \nContact: \n  apo@seas.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160829T120000
DTEND;TZID=America/New_York:20160829T130000
LAST-MODIFIED:20160620T153223Z
SUMMARY:Lunch with OPA!s and Departmental Faculty
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-160000-2016-08-29-1
 70000/lunch-opas-and-departmental-faculty
END:VEVENT
BEGIN:VEVENT
UID:calendar.308.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T160940Z
DESCRIPTION:Penn Engineering Departmental Meeting\n\n              \n\n\nMa
 ndatory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 201
 6 - \n11:30 am to 12:00 pm\n      \nEvent Location: \n  Location announced
  at Dean’s Meeting\n\n              \nHost: \n  School of Engineering & Ap
 plied Sciences \n      \n      \nDescription: \n  \n\nMeet departmental fa
 culty and staff in the major or program you plan to pursue at Penn. Locati
 ons will be announced at the Dean’s meeting\, or ask your OPA! for details
 .\n\n      \n\n      \nContact: \n  apo@seas.upenn.edu for more informatio
 n.
DTSTART;TZID=America/New_York:20160829T113000
DTEND;TZID=America/New_York:20160829T120000
LAST-MODIFIED:20160620T153112Z
SUMMARY:Penn Engineering Departmental Meeting
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-153000-2016-08-29-1
 60000/penn-engineering-departmental-meeting
END:VEVENT
BEGIN:VEVENT
UID:calendar.306.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T155725Z
DESCRIPTION:Fun Activity with Your OPA!\n\n              \n\n\nMandatory: Y
 es\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n10:3
 0 am to 11:15 am\n      \nEvent Location: \n  Your OPA! will inform you. 
 \n\n              \nHost: \n  School of Engineering & Applied Sciences \n 
      \n      \nDescription: \n  \n\nHave fun with your OPA! and other fres
 hmen. \n\n      \n\n      \nContact: \n  apo@seas.upenn.edu for more infor
 mation.
DTSTART;TZID=America/New_York:20160829T103000
DTEND;TZID=America/New_York:20160829T111500
LAST-MODIFIED:20160708T182018Z
SUMMARY:Fun Activity with Your OPA!
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-143000-2016-08-29-1
 51500/fun-activity-your-opa
END:VEVENT
BEGIN:VEVENT
UID:calendar.305.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T155129Z
DESCRIPTION:Penn Engineering Dean’s Meeting\n\n              \n\n\nMandator
 y: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n
 10:00 am to 10:30 am\n      \nEvent Location: \n  Zellerbach Theatre\, Ann
 enberg Center\n\n              \nHost: \n  School of Engineering & Applied
  Sciences \n      \n      \nDescription: \n  \n\nMeet the Deans and admini
 strators from the Office of Academic Programs as you are welcomed to Penn 
 Engineering.  This information meeting will introduce you to Penn Engineer
 ing and provide you with an overview of the School. \n\n      \n\n      \n
 Contact: \n  apo@seas.upenn.edu for more information.\n\n      \n\n  \n\n
 \nView larger map
DTSTART;TZID=America/New_York:20160829T100000
DTEND;TZID=America/New_York:20160829T103000
LAST-MODIFIED:20160708T201733Z
LOCATION:3680 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Penn Engineering Dean’s Meeting
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-140000-2016-08-29-1
 43000/penn-engineering-dean%E2%80%99s-meeting
END:VEVENT
BEGIN:VEVENT
UID:calendar.304.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T154547Z
DESCRIPTION:Meet Your OPA!\n\n              \n\n\nMandatory: Yes\n      \n 
      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n9:30 am to 9:45 a
 m\n      \nEvent Location: \n  Your OPA! will tell you where to meet.\n\n 
              \nHost: \n  School of Engineering & Applied Sciences \n      
 \n      \nDescription: \n  \n\nMeet your OPA! at the designated spot to wa
 lk over together to the Dean’s Meeting.\n\n      \n\n      \nContact: \n  
 apo@seas.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160829T093000
DTEND;TZID=America/New_York:20160829T094500
LAST-MODIFIED:20160708T182010Z
SUMMARY:Meet Your OPA!
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-133000-2016-08-29-1
 34500/meet-your-opa
END:VEVENT
BEGIN:VEVENT
UID:calendar.303.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T154110Z
DESCRIPTION:Water Ice and Campus Tour with the Nursing Peer Advisors\n\n   
            \n\n\nMandatory: Yes\n      \n      \n      \nDate & Time: \n  
 Monday\, Aug 29 2016 - \n2:00 pm to 3:30 pm\n      \nEvent Location: \n  D
 eparts from Carol Ware Lobby\, Claire M. Fagin Hall\n\n              \nHos
 t: \n  School of Nursing \n      \n      \nDescription: \n  \n\nEnjoy a wa
 ter ice and join the Nursing Peer Advisors for a tour of campus and tips o
 n their campus and Philly favorites.\n\n      \n\n      \nContact: \n  adv
 isor@nursing.upenn.edu  for more information.\n\n      \n\n  \n\n\nView la
 rger map
DTSTART;TZID=America/New_York:20160829T140000
DTEND;TZID=America/New_York:20160829T153000
LAST-MODIFIED:20160630T155026Z
LOCATION:418 Curie Boulevard\, Philadelphia\, PA 19104
SUMMARY:Water Ice and Campus Tour with the Nursing Peer Advisors
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-180000-2016-08-29-1
 93000/water-ice-and-campus-tour-nursing-peer-advisors
END:VEVENT
BEGIN:VEVENT
UID:calendar.302.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T153919Z
DESCRIPTION:Resource Fair and Welcome Picnic\n\n              \n\n\nMandato
 ry: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - 
 \n1:00 pm to 2:00 pm\n      \nEvent Location: \n  Carol Ware Lobby\, Clair
 e M. Fagin Hall\n\n              \nHost: \n  School of Nursing \n      \n 
      \nDescription: \n  \n\nGet to know your classmates and the Penn Nursi
 ng Peer Advisors during this picnic lunch celebrating the Class of 2020!  
 After lunch\, learn about the many campus resources and the Penn Nursing s
 tudent organizations.\n\n      \n\n      \nContact: \n  advisor@nursing.up
 enn.edu  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T130000
DTEND;TZID=America/New_York:20160829T140000
LAST-MODIFIED:20160630T154947Z
LOCATION:418 Curie Boulevard\, Philadelphia\, PA 19104
SUMMARY:Resource Fair and Welcome Picnic
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-170000-2016-08-29-1
 80000/resource-fair-and-welcome-picnic
END:VEVENT
BEGIN:VEVENT
UID:calendar.301.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T153752Z
DESCRIPTION:If I Knew Then\, What I Know Now…  \n\n              \n\n\nMand
 atory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 
 - \n12:00 pm to 1:00 pm\n      \nEvent Location: \n  Ann L. Roy Auditorium
 \, Claire M. Fagin Hall\n\n              \nHost: \n  School of Nursing \n 
      \n      \nDescription: \n  \n\nNursing Peer Advisors share helpful hi
 nts for being successful and making the most of your Penn Nursing experien
 ce.  After the panel\, there will be time for open Q&A and an opportunity 
 to get to know your Peer Advisor.   \n\n      \n\n      \nContact: \n  adv
 isor@nursing.upenn.edu  for more information.\n\n      \n\n  \n\n\nView la
 rger map
DTSTART;TZID=America/New_York:20160829T120000
DTEND;TZID=America/New_York:20160829T130000
LAST-MODIFIED:20160630T154810Z
LOCATION:418 Curie Boulevard\, Philadelphia\, PA 19104
SUMMARY:If I Knew Then\, What I Know Now…
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-160000-2016-08-29-1
 70000/if-i-knew-then-what-i-know-now%E2%80%A6
END:VEVENT
BEGIN:VEVENT
UID:calendar.299.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T153354Z
DESCRIPTION:Dean's Meeting\n\n      \n              \n\n\nMandatory: No\n  
     \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n11:00 am to 12:00 
 pm\n      \nEvent Location: \n  Ann L. Roy Auditorium\, Claire M. Fagin Ha
 ll\n\n              \nHost: \n  School of Nursing\n      \n      \nDescrip
 tion: \n  \n\nDean Antonia Villarruel\, Associate Dean for Academic Progra
 ms Dr. Julie Sochalski\, and the Office of Academic Affairs staff welcome 
 the Class of 2020 and provide an overview of the School\, support services
 \, and student life.\n\n      \n\n      \nContact: \n  advisor@nursing.upe
 nn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T110000
DTEND;TZID=America/New_York:20160829T120000
LAST-MODIFIED:20160708T181813Z
LOCATION:418 Curie Boulevard\, Philadelphia\, PA 19104.
SUMMARY:Dean's Meeting
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-150000-2016-08-29-1
 60000/deans-meeting
END:VEVENT
BEGIN:VEVENT
UID:calendar.298.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T152238Z
DESCRIPTION:Welcome to the College/ Academic Tour B\n\n              \n\n\n
 Mandatory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2
 016 - \n2:00 pm to 3:30 pm\n      \nEvent Location: \n  Irvine Auditorium 
 \n\n              \nHost: \n  College of Arts and Sciences\n      \n      
 \nDescription: \n  \n\nYou will begin the day with one of two sessions. Yo
 ur Peer Advisor will let you know which.\nWelcome to the College\, an intr
 oduction to the Arts and Sciences with the College Dean\, or\nCampus Acade
 mic Tour\, where Peer Advisors will escort you around campus to acquaint y
 ou with academic departments\, academic support programs\, and other resou
 rces.\n\n\nAfter lunch\, attend the session you did not attend in the morn
 ing.\n\n\nAcademic Tour Location: Check with your Peer Advisor\n\n      \n
 \n      \nContact: \n  college@sas.upenn.edu for more information.\n\n    
   \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T140000
DTEND;TZID=America/New_York:20160829T153000
LAST-MODIFIED:20160729T151533Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Welcome to the College/ Academic Tour B
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-180000-2016-08-29-1
 93000/welcome-college-academic-tour-b
END:VEVENT
BEGIN:VEVENT
UID:calendar.297.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T151712Z
DESCRIPTION:Welcome to the College/ Academic Tour A \n\n              \n\n
 \nMandatory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29
  2016 - \n11:00 am to 12:30 pm\n      \nEvent Location: \n  Irvine Auditor
 ium \n\n              \nHost: \n  College of Arts and Sciences\n      \n  
     \nDescription: \n  \n\nYou will begin the day with one of two sessions
 . Your Peer Advisor will let you know which.\nWelcome to the College\, an 
 introduction to the Arts and Sciences with the College Dean\, or\nCampus A
 cademic Tour\, where Peer Advisors will escort you around campus to acquai
 nt you with academic departments\, academic support programs\, and other r
 esources.\n\n\nAfter lunch\, attend the session you did not attend in the 
 morning.\n\n\nAcademic Tour Location: Check with your Peer Advisor\n\n    
   \n\n      \nContact: \n  college@sas.upenn.edu for more information.\n\n
       \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T110000
DTEND;TZID=America/New_York:20160829T123000
LAST-MODIFIED:20160729T151527Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Welcome to the College/ Academic Tour A
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-150000-2016-08-29-1
 63000/welcome-college-academic-tour
END:VEVENT
BEGIN:VEVENT
UID:calendar.293.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160615T144742Z
DESCRIPTION:President and Provost’s Reception\n\n              \n\n\nMandat
 ory: Yes\n      \n      \n      \nDate & Time: \n  Monday\, Aug 29 2016 - 
 \n8:15 pm to 9:30 pm\n      \nEvent Location: \n  Tent on Wynn Commons\n\n
       \n      \nDescription: \n  \n\nEnjoy a delicious dessert reception t
 o celebrate Convocation.\n\n      \n\n      \nContact: \n  provost-nso-ai@
 pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160829T201500
DTEND;TZID=America/New_York:20160829T213000
LAST-MODIFIED:20160720T200857Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:President and Provost’s Reception
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-30-001500-2016-08-30-0
 13000/president-and-provost%E2%80%99s-reception
END:VEVENT
BEGIN:VEVENT
UID:calendar.286.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T212724Z
DESCRIPTION:Convocation\n\n              \n\n\nMandatory: Yes\n      \n    
   \n      \nDate & Time: \n  Monday\, Aug 29 2016 - \n7:00 pm to 8:15 pm\n
       \nEvent Location: \n  College Green\n\n      \n      \nDescription: 
 \n  \n\nThis formal ceremony inducts incoming classes to the Penn communit
 y.\n\n\nRain Location: The Palestra\n\n      \n\n      \nContact: \n  prov
 ost-nso-ai@pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView
  larger map
DTSTART;TZID=America/New_York:20160829T190000
DTEND;TZID=America/New_York:20160829T201500
LAST-MODIFIED:20160701T172101Z
LOCATION:College Hall\, Philadelphia\, PA 19104
SUMMARY:Convocation
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-230000-2016-08-30-0
 01500/convocation
END:VEVENT
BEGIN:VEVENT
UID:calendar.284.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T211352Z
DESCRIPTION:Dinner\n\n      \n              \n\n\nMandatory: No\n      \n  
     \nDate & Time: \n  Monday\, Aug 29 2016 - \n4:00 pm to 7:00 pm\n      
 \nEvent Location: \n  Various Locations\n\n              \nHost: \n  Penn 
 Dining \n      \n      \nDescription: \n  \n\nAsk your RAs or GAs for deta
 ils. Kings Court English\, NCH\, and 1920 Commons dining halls. Kosher din
 ner available at Falk Dining in Hillel\, 4:30pm-7pm.\n\n      \n\n      \n
 Contact: \n  dining@upenn.edu for more information.
DTSTART;TZID=America/New_York:20160829T160000
DTEND;TZID=America/New_York:20160829T190000
LAST-MODIFIED:20160729T160526Z
SUMMARY:Dinner
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-200000-2016-08-29-2
 30000/dinner
END:VEVENT
BEGIN:VEVENT
UID:calendar.283.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T211101Z
DESCRIPTION:Brunch \n\n      \n              \n\n\nMandatory: No\n      \n 
      \nDate & Time: \n  Monday\, Aug 29 2016 - \n10:30 am to 2:30 pm\n    
   \nEvent Location: \n  Various Locations\n\n              \nHost: \n  Pen
 n Dining \n      \n      \nDescription: \n  \n\nKings Court English\, NCH\
 , and 1920 Commons dining halls. Kosher lunch available at Falk dining in 
 Hillel\, 11:30am-2pm.\n\n      \n\n      \nContact: \n  dining@upenn.edu f
 or more information.
DTSTART;TZID=America/New_York:20160829T103000
DTEND;TZID=America/New_York:20160829T143000
LAST-MODIFIED:20160804T143727Z
SUMMARY:Brunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-143000-2016-08-29-1
 83000/brunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.282.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T210138Z
DESCRIPTION:Late Night Events\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  \nSunday\, Aug 28 2016 - 11:00 pm to Mo
 nday\, Aug 29 2016 - 1:00 am\n      \nEvent Location: \n  Various Location
 s\n\n      \n      \nDescription: \n  \n\nSponsored by student organizatio
 ns. See Late Nights.\n\n      \n\n      \nContact: \n  provost-nso-ai@pobo
 x.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160828T230000
DTEND;TZID=America/New_York:20160829T010000
LAST-MODIFIED:20160708T191124Z
SUMMARY:Late Night Events
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-030000-2016-08-29-0
 50000/late-night-events
END:VEVENT
BEGIN:VEVENT
UID:calendar.281.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T205821Z
DESCRIPTION:Toga Party at the Penn Museum\n\n      \n              \n\n\nMa
 ndatory: No\n      \n      \nDate & Time: \n  Sunday\, Aug 28 2016 - \n9:0
 0 pm to 11:00 pm\n      \nEvent Location: \n  University of Pennsylvania M
 useum of Archaeology and Anthropology\n\n      \n      \nDescription: \n  
 \n\nTake a journey through time with the Penn Museum. Experience renowned 
 collections from around the world. Dine in the magnificent Chinese Rotunda
 \, and dance among the sarcophagi of mighty pharaohs. The Penn Museum invi
 tes you to this unique Penn tradition.\n\n\nIn the spirit of the night\, a
 ll are invited to dress in the garb of the ancient world\, and togas aboun
 d – some beautiful\, some outrageous\, and all radically creative. Prizes 
 will be awarded for the best costumes by a panel of seasoned judges. Our D
 J keeps things hot for those who like to dance\, and the scavenger hunt lu
 res you into gallery after gallery.\n\n\nDelve deep into the palace of New
  Kingdom pharaoh Merenptah (r. 1213-1204 BCE) in the Sphinx Gallery at the
  Penn Museum\, the only museum in the world to exhibit such a significant 
 portion of an Egyptian royal palace. The space derives its name from the m
 assive sphinx\, the third largest in the world\, weighing in at approximat
 ely twelve tons. The sphinx passed from Ramesses II to Merenptah\, from fa
 ther to son\, and now guards one of the most impressive collections of Egy
 ptian artifacts in the United States.\n\n\nExplore our newest exhibition\,
  The Golden Age of King Midas\, about the historical King Midas who lived 
 in the prosperous city of Gordion\, the political and cultural capital of 
 the Phrygians nearly 3\,000 years ago. In 1957\, Penn Museum archaeologist
 s excavated a spectacular royal tomb believed to be the final resting plac
 e of King Midas’ father Gordios. Dating to ca. 740 BCE\, the tomb containe
 d a treasure trove of magnificent objects from the time of Midas. Come see
  this world-exclusive exhibition developed by the Penn Museum in partnersh
 ip with the Republic of Turkey and view more than 120 dazzling objects on 
 special loan from Turkish museums in Ankara\, Istanbul\, Antalya\, and Gor
 dion.\n\n\nTo learn more about the Penn Museum’s fascinating history\, col
 lections\, exhibitions\, research\, and student events & opportunities\, v
 isit www.penn.museum.\n\n\nWith proud support from the Undergraduate Assem
 bly. \n\n      \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for
  more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160828T210000
DTEND;TZID=America/New_York:20160828T230000
LAST-MODIFIED:20160721T145917Z
LOCATION:3260 South St\, Philadelphia\, PA 19104
SUMMARY:Toga Party at the Penn Museum
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-29-010000-2016-08-29-0
 30000/toga-party-penn-museum
END:VEVENT
BEGIN:VEVENT
UID:calendar.280.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T204707Z
DESCRIPTION:College House Activities\n\n              \n\n\nMandatory: Yes
 \n      \n      \n      \nDate & Time: \n  Sunday\, Aug 28 2016 - \n7:00 p
 m to 9:00 pm\n      \nEvent Location: \n  Various Locations\n\n           
    \nHost: \n  College Houses & Academic Services \n      \n      \nDescri
 ption: \n  \n\nAll residents are invited to attend various College House e
 vents. See your RA/GA for more info.\n\n      \n\n      \nContact: \n  liv
 ing@exchange.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160828T190000
DTEND;TZID=America/New_York:20160828T210000
LAST-MODIFIED:20160708T190815Z
SUMMARY:College House Activities
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-230000-2016-08-29-0
 10000/college-house-activities
END:VEVENT
BEGIN:VEVENT
UID:calendar.278.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T203949Z
DESCRIPTION:Penn Athletics Picnic and Class of 2020 Photo\n\n      \n      
         \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Sunday\, Aug
  28 2016 - \n5:00 pm to 7:00 pm\n      \nEvent Location: \n  Penn Park\n\n
       \n      \nDescription: \n  \n\nHead over to Penn Park where dinner (
 including Kosher options) will be available. Penn Traditions and the Red a
 nd Blue Crew will be giving out the official Class of 2020 t-shirts. Show 
 your Penn pride and wear it for the official class photo! The Penn Athleti
 cs Picnic is your sole dining option for this evening. Penn ID and NSO wri
 stbands required.\n\n\nRain Location: Class of 1923 Ice Rink\n\n      \n\n
       \nContact: \n  provost-nso-ai@pobox.upenn.edu for more information.
 \n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160828T170000
DTEND;TZID=America/New_York:20160828T190000
LAST-MODIFIED:20160701T172339Z
LOCATION:3000 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Penn Athletics Picnic and Class of 2020 Photo
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-210000-2016-08-28-2
 30000/penn-athletics-picnic-and-class-2020-photo
END:VEVENT
BEGIN:VEVENT
UID:calendar.277.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T202533Z
DESCRIPTION:The Penn Reading Project\n\n              \n\n\nMandatory: Yes
 \n      \n      \n      \nDate & Time: \n  Sunday\, Aug 28 2016 - \n11:45 
 am to 5:00 pm\n      \nEvent Location: \n  Various Locations\n\n      \n  
     \nDescription: \n  \n\nThe Penn Reading Project\, sponsored by the Cou
 ncil of Undergraduate Deans\, creates an opportunity for the Class of 2020
  and Penn faculty from all disciplines to share a unifying intellectual ex
 perience through a single text\, film\, or painting. This year's selection
  is Orson Welles' Citizen Kane\, which is an American classic about the ri
 se and fall of Charles Foster Kane through the various themes of power and
  isolation with the usage of media.\n\n\nAll freshmen are required to atte
 nd an introductory presentation featuring Penn faculty. Later in the after
 noon\, freshmen will meet with their small groups for a 90-minute session 
 to discuss their essays submitted through Canvas and Citizen Kane with a f
 aculty discussion leader.\n\n\nWith the kick off of PRP 2016\, the Office 
 of New Student Orientation and Academic Initiatives will launch the Year o
 f Media\, featuring programs and events intended to engage the entire Penn
  community in exploring media and the many ways it shapes our lives. Visit
  the theme year website for more details at www.yearofmedia.org.\n\n\n11:4
 5am Lunch / 1:30pm Panel in Irvine AuditoriumBlue NSO Wristband: Du Bois\,
  Gregory\, New\, Stouffer\, and Ware College Houses\n\n\n11:45am Panel in 
 Irvine Auditorium / 1:30pm LunchRed NSO Wristband: Fisher Hassenfeld\, Har
 rison\, Kings Court English\, and Riepe College Houses\n\n\n3:30pm-5pm Sma
 ll Group DiscussionsLocation: Room assignments will be available in mid-Au
 gust\n\n      \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for 
 more information.
DTSTART;TZID=America/New_York:20160828T114500
DTEND;TZID=America/New_York:20160828T170000
LAST-MODIFIED:20160718T142713Z
SUMMARY:The Penn Reading Project
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-154500-2016-08-28-2
 10000/penn-reading-project
END:VEVENT
BEGIN:VEVENT
UID:calendar.276.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T201346Z
DESCRIPTION:Brunch\n\n      \n              \n\n\nMandatory: No\n      \n  
     \nDate & Time: \n  Sunday\, Aug 28 2016 - \n10:00 am to 2:30 pm\n     
  \nEvent Location: \n  Various Locations\n\n              \nHost: \n  Penn
  Dining \n      \n      \nDescription: \n  \n\nKings Court English\, NCH\,
  and 1920 Commons dining halls. Kosher picnic at Hillel\, 12pm-2pm.\n\n   
    \n\n      \nContact: \n  dining@upenn.edu for more information.
DTSTART;TZID=America/New_York:20160828T100000
DTEND;TZID=America/New_York:20160828T143000
LAST-MODIFIED:20160729T160507Z
SUMMARY:Brunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-140000-2016-08-28-1
 83000/brunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.275.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T194729Z
DESCRIPTION:Late Night Events\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  \nSaturday\, Aug 27 2016 - 10:00 pm to 
 Sunday\, Aug 28 2016 - 1:00 am\n      \nEvent Location: \n  Houston Hall\n
 \n      \n      \nDescription: \n  \n\nSponsored by student organizations.
  See Late Nights.\n\n      \n\n      \nContact: \n  provost-nso-ai@pobox.u
 penn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T220000
DTEND;TZID=America/New_York:20160828T010000
LAST-MODIFIED:20160701T172158Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Late Night Events
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-020000-2016-08-28-0
 50000/late-night-events
END:VEVENT
BEGIN:VEVENT
UID:calendar.274.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T193847Z
DESCRIPTION:Comedy Night at Irvine \n\n      \n              \n\n\nMandator
 y: No\n      \n      \nDate & Time: \n  Saturday\, Aug 27 2016 - 10:00 pm
 \n      \nEvent Location: \n  Irvine Auditorium \n\n      \n      \nDescri
 ption: \n  \n\nEnjoy an evening of laughs with professional stand-up comed
 ians.\n\n      \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for
  more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T220000
DTEND;TZID=America/New_York:20160827T220000
LAST-MODIFIED:20160720T195929Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Comedy Night at Irvine
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-020000/comedy-night
 -irvine
END:VEVENT
BEGIN:VEVENT
UID:calendar.273.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T193345Z
DESCRIPTION:Late Night at Pottruck\n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Saturday\, Aug 27 2016 - \n9:30 pm 
 to 11:30 pm\n      \nEvent Location: \n   Pottruck Fitness Center\n\n     
  \n      \nDescription: \n  \n\nJoin Campus Recreation for a night of free
  food\, rock climbing\, Zumba\, swimming\, basketball\, and a wide variety
  of free programming for students of all fitness levels. Our gyms and pool
  will be open to all students. Please dress accordingly.\n\n      \n\n    
   \nContact: \n  provost-nso-ai@pobox.upenn.edu for more information.\n\n 
      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T213000
DTEND;TZID=America/New_York:20160827T233000
LAST-MODIFIED:20160720T194410Z
LOCATION:3701 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Late Night at Pottruck
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-013000-2016-08-28-0
 33000/late-night-pottruck
END:VEVENT
BEGIN:VEVENT
UID:calendar.272.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T165225Z
DESCRIPTION:NSO Speakeasy\n\n      \n              \n\n\nMandatory: No\n   
    \n      \nDate & Time: \n  Saturday\, Aug 27 2016 - 9:30 pm\n      \nEv
 ent Location: \n  Kelly Writers House Garden\n\n      \n      \nDescriptio
 n: \n  \n\nThis open mic night features performances by the Class of 2020.
  Bring your poetry\, your guitar\, or your award-winning essay and share y
 our talents with your classmates. Or just come to hang out\, listen\, and 
 check out the Writers House.\n\n      \n\n      \nContact: \n  provost-nso
 -ai@pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger
  map
DTSTART;TZID=America/New_York:20160827T213000
DTEND;TZID=America/New_York:20160827T213000
LAST-MODIFIED:20160701T172142Z
LOCATION:3805 Locust Walk Philadelphia\, PA 19104
SUMMARY:NSO Speakeasy
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-28-013000/nso-speakeas
 y
END:VEVENT
BEGIN:VEVENT
UID:calendar.271.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T164419Z
DESCRIPTION:Evening at the Philadelphia Museum of Art\n\n      \n          
     \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Saturday\, Aug 2
 7 2016 - \n6:30 pm to 9:30 pm\n      \nEvent Location: \n  Philadelphia Mu
 seum of Art\n\n      \n      \nDescription: \n  \n\nJoin your classmates f
 or a fun and inspiring evening at one of the world’s greatest art museums.
  Enjoy festive food while discovering the world-renowned collections of As
 ian\, European\, American\, and Contemporary art.  Take in a spectacular v
 iew of the Philadelphia skyline and tackle the famous Rocky steps from thi
 s Philadelphia landmark.\n\n\nPlease bring your Penn ID and wear your NSO 
 wristband. Casual attire is recommended.  Dinner and dessert will be serve
 d through 8:30pm. Free shuttle bus transportation will begin at 6:30 pm an
 d will run continuously between the Museum and the pick-up/drop-off points
  listed below. The Museum is also within walking distance of Center City a
 nd Penn’s campus\, and taxicabs are readily available.\n\n\nBus Stops\n\n
 \n• 15th and Market streets (initial pick up at 6:30pm only)\n\n\n• 34th a
 nd Walnut streets\n\n\n• 37th and Spruce streets (Upper Quad Gate)\n\n\n• 
 40th and Locust streets\n\n\nTo learn more about this world-class institut
 ion\, Philadelphia’s finest museum\, visit www.philamuseum.org.\n\n\nIf yo
 u would like to request fully accessible transportation to the Philadelphi
 a Museum of Art event\, please contact the Office of Student Disabilities 
 Services.\n\n\nPhone 215.573.9235           TTY 215.746.6320        Email 
 sdsmail@zimbra.upenn.edu\n\n      \n\n      \nContact: \n  provost-nso-ai@
 pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T183000
DTEND;TZID=America/New_York:20160827T213000
LAST-MODIFIED:20160720T194336Z
LOCATION:2600 Benjamin Franklin Pkwy\, Philadelphia\, PA 19130
SUMMARY:Evening at the Philadelphia Museum of Art
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-223000-2016-08-28-0
 13000/evening-philadelphia-museum-art
END:VEVENT
BEGIN:VEVENT
UID:calendar.270.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T164029Z
DESCRIPTION:NSO Preceptorials\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  Saturday\, Aug 27 2016 - \n3:30 pm to 6
 :00 pm\n      \nEvent Location: \n  Various Locations\n\n      \n      \nD
 escription: \n  \n\nThese informal sampler courses offer a taste of the im
 aginative and varied academic discourse at Penn. See Preceptorials. \n\n  
     \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more infor
 mation.
DTSTART;TZID=America/New_York:20160827T153000
DTEND;TZID=America/New_York:20160827T180000
LAST-MODIFIED:20160708T185823Z
SUMMARY:NSO Preceptorials
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-193000-2016-08-27-2
 20000/nso-preceptorials
END:VEVENT
BEGIN:VEVENT
UID:calendar.269.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T162831Z
DESCRIPTION:Penn Life Sketches Red NSO Wristband \n\n              \n\n\nMa
 ndatory: Yes\n      \n      \n      \nDate & Time: \n  Saturday\, Aug 27 2
 016 - \n1:30 pm to 3:30 pm\n      \nEvent Location: \n  Zellerbach Theatre
 \, Annenberg Center\n\n      \n      \nDescription: \n  \n\nPerformances b
 y the PHINS about the freshman experience.\n\n\nRed NSO Wristband: Fisher 
 Hassenfeld\, Harrison\, Kings Court English\, and Riepe College Houses\n\n
       \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more inf
 ormation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T133000
DTEND;TZID=America/New_York:20160827T153000
LAST-MODIFIED:20160729T160734Z
LOCATION:3680 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Penn Life Sketches Red NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-173000-2016-08-27-1
 93000/penn-life-sketches-red-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.268.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T161343Z
DESCRIPTION:Penn Life Sketches Blue NSO Wristband \n\n              \n\n\nM
 andatory: Yes\n      \n      \n      \nDate & Time: \n  Saturday\, Aug 27 
 2016 - \n11:30 am to 1:00 pm\n      \nEvent Location: \n  Zellerbach Theat
 re\, Annenberg Center\n\n      \n      \nDescription: \n  \n\nPerformances
  by the PHINS about the freshman experience.\n\n\nBlue NSO Wristband: Du B
 ois\, Gregory\, NCH\, Stouffer\, and Ware College Houses\n\n      \n\n    
   \nContact: \n  provost-nso-ai@pobox.upenn.edu for more information.\n\n 
      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160827T113000
DTEND;TZID=America/New_York:20160827T130000
LAST-MODIFIED:20160729T160724Z
LOCATION:3680 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Penn Life Sketches Blue NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-153000-2016-08-27-1
 70000/penn-life-sketches-blue-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.267.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T161102Z
DESCRIPTION:Brunch \n\n      \n              \n\n\nMandatory: No\n      \n 
      \nDate & Time: \n  Saturday\, Aug 27 2016 - \n10:00 am to 2:30 pm\n  
     \nEvent Location: \n  Various Locations\n\n              \nHost: \n  P
 enn Dining \n      \n      \nDescription: \n  \n\nKings Court English\, NC
 H\, and 1920 Commons dining halls. Shabbat lunch at Falk Dining in Hillel\
 , 11:30am-2pm.\n\n      \n\n      \nContact: \n  dining@upenn.edu for more
  information.
DTSTART;TZID=America/New_York:20160827T100000
DTEND;TZID=America/New_York:20160827T143000
LAST-MODIFIED:20160729T160456Z
SUMMARY:Brunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-140000-2016-08-27-1
 83000/brunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.266.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T160434Z
DESCRIPTION:PennFest 2016\n\n      \n              \n\n\nMandatory: No\n   
    \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n9:00 pm to 11:00 pm
 \n      \nEvent Location: \n  Wynn Commons and Houston Hall \n\n      \n  
     \nDescription: \n  \n\nThis indoor/outdoor festival features a casino 
 room\, Penn Quizzo\, and delicious treats from Philly vendors.\n\n      \n
 \n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more information
 .\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T210000
DTEND;TZID=America/New_York:20160826T230000
LAST-MODIFIED:20160701T172044Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:PennFest 2016
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-010000-2016-08-27-0
 30000/pennfest-2016
END:VEVENT
BEGIN:VEVENT
UID:calendar.265.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T160222Z
DESCRIPTION:Penn Bookstore Social \n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n8:00 pm to
  10:00 pm\n      \nEvent Location: \n  Penn Bookstore \n\n      \n      \n
 Description: \n  \n\nWelcome to Penn's comprehensive and comfortable books
 tore - a great place to shop and hang out. Enjoy live music and desserts i
 n the 2nd floor café.\n\n      \n\n      \nContact: \n  provost-nso-ai@pob
 ox.upenn.edu for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T200000
DTEND;TZID=America/New_York:20160826T220000
LAST-MODIFIED:20160722T144452Z
LOCATION:3601 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Penn Bookstore Social
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-27-000000-2016-08-27-0
 20000/penn-bookstore-social
END:VEVENT
BEGIN:VEVENT
UID:calendar.264.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T155346Z
DESCRIPTION:Dinner\n\n      \n              \n\n\nMandatory: No\n      \n  
     \nDate & Time: \n  Friday\, Aug 26 2016 - \n5:00 pm to 8:00 pm\n      
 \nEvent Location: \n  Various Locations\n\n              \nHost: \n  Penn 
 Dining \n      \n      \nDescription: \n  \n\nKings Court English\, NCH\, 
 and 1920 Commons dining halls. Shabbat dinner at Falk Dining in Hillel at 
 8:30pm.\n\n      \n\n      \nContact: \n  dining@upenn.edu for more inform
 ation.
DTSTART;TZID=America/New_York:20160826T170000
DTEND;TZID=America/New_York:20160826T200000
LAST-MODIFIED:20160729T160444Z
SUMMARY:Dinner
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-210000-2016-08-27-0
 00000/dinner
END:VEVENT
BEGIN:VEVENT
UID:calendar.263.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T155124Z
DESCRIPTION:Speak About It Red NSO Wristband \n\n              \n\n\nMandat
 ory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - 
 \n4:00 pm to 5:00 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n  
     \n      \nDescription: \n  \n\nA performance about consent\, boundarie
 s\, and healthy relationships.\n\n\nRed NSO Wristband: Fisher Hassenfeld\,
  Harrison\, Kings Court English\, and Riepe College Houses\n\n      \n\n  
     \nContact: \n  provost-nso-ai@pobox.upenn.edu for more information.\n
 \n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T160000
DTEND;TZID=America/New_York:20160826T170000
LAST-MODIFIED:20160729T160711Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Speak About It Red NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-200000-2016-08-26-2
 10000/speak-about-it-red-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.262.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T154809Z
DESCRIPTION:Speak About It Blue NSO Wristband \n\n              \n\n\nManda
 tory: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 -
  \n2:30 pm to 3:30 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n 
      \n      \nDescription: \n  \n\nA performance about consent\, boundari
 es\, and healthy relationships.\n\n\nBlue NSO Wristband: Du Bois\, Gregory
 \, NCH\, Stouffer\, and Ware College Houses\n\n      \n\n      \nContact: 
 \n  provost-nso-ai@pobox.upenn.edu for more information.\n\n      \n\n  \n
 \n\nView larger map
DTSTART;TZID=America/New_York:20160826T143000
DTEND;TZID=America/New_York:20160826T153000
LAST-MODIFIED:20160729T160701Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Speak About It Blue NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-183000-2016-08-26-1
 93000/speak-about-it-blue-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.261.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T154333Z
DESCRIPTION:Safe Living Red NSO Wristband \n\n              \n\n\nMandatory
 : Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n1
 2:30 pm to 2:00 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n    
   \n      \nDescription: \n  \n\nSafe living is your guide to working and 
 relaxing safely at Penn.\n\n\nRed NSO Wristband: Fisher Hassenfeld\, Harri
 son\, Kings Court English\, and Riepe College Houses\n\n      \n\n      \n
 Contact: \n  provost-nso-ai@pobox.upenn.edu for more information.\n\n     
  \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160826T123000
DTEND;TZID=America/New_York:20160826T140000
LAST-MODIFIED:20160729T160807Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Safe Living Red NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-163000-2016-08-26-1
 80000/safe-living-red-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.259.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T153958Z
DESCRIPTION:Safe Living Blue NSO Wristband \n\n              \n\n\nMandator
 y: Yes\n      \n      \n      \nDate & Time: \n  Friday\, Aug 26 2016 - \n
 10:30 am to 12:00 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n  
     \n      \nDescription: \n  \n\nSafe living is your guide to working an
 d relaxing safely at Penn.\n\n\nBlue NSO Wristband: Du Bois\, Gregory\, NC
 H\, Stouffer\, and Ware College Houses\n\n      \n\n      \nContact: \n  p
 rovost-nso-ai@pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nV
 iew larger map
DTSTART;TZID=America/New_York:20160826T103000
DTEND;TZID=America/New_York:20160826T120000
LAST-MODIFIED:20160729T160749Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Safe Living Blue NSO Wristband
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-143000-2016-08-26-1
 60000/safe-living-blue-nso-wristband
END:VEVENT
BEGIN:VEVENT
UID:calendar.257.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T153355Z
DESCRIPTION:Brunch \n\n      \n              \n\n\nMandatory: No\n      \n 
      \nDate & Time: \n  Friday\, Aug 26 2016 - \n10:30 am to 2:30 pm\n    
   \nEvent Location: \n  Various Locations\n\n              \nHost: \n  Pen
 n Dining \n      \n      \nDescription: \n  \n\nKings Court English\, NCH\
 , and 1920 Commons dining halls. Kosher buffet available at Falk Dining in
  Hillel\, 11:30am-2pm.\n\n      \n\n      \nContact: \n  dining@upenn.edu 
 for more information.
DTSTART;TZID=America/New_York:20160826T103000
DTEND;TZID=America/New_York:20160826T143000
LAST-MODIFIED:20160729T160429Z
SUMMARY:Brunch
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-143000-2016-08-26-1
 83000/brunch
END:VEVENT
BEGIN:VEVENT
UID:calendar.256.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T153106Z
DESCRIPTION:Penn Traditions Highball to Hey Day\n\n      \n              \n
 \n\nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016
  - 10:30 pm\n      \nEvent Location: \n  Irvine Auditorium \n\n           
    \nHost: \n  Penn Traditions\n      \n      \nDescription: \n  \n\nJoin 
 Penn Traditions for snacks\, games\, and fun! Learn Penn songs and sign yo
 ur class banner!\n\n      \n\n      \nContact: \n  alumni@ben.dev.upenn.ed
 u for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T223000
DTEND;TZID=America/New_York:20160825T223000
LAST-MODIFIED:20160617T205819Z
LOCATION:3401 Spruce Street Philadelphia PA\, 19104
SUMMARY:Penn Traditions Highball to Hey Day
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-26-023000/penn-traditi
 ons-highball-hey-day
END:VEVENT
BEGIN:VEVENT
UID:calendar.255.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T152304Z
DESCRIPTION:College House Meetings and Activities for Students Only\n\n    
           \n\n\nMandatory: Yes\n      \n      \n      \nDate & Time: \n  T
 hursday\, Aug 25 2016 - \n7:30 pm to 10:30 pm\n      \nEvent Location: \n 
  Various Locations\n\n              \nHost: \n  College Houses & Academic 
 Services \n      \n      \nDescription: \n  \n\nAttendance required for ma
 ndatory College House meetings and activities with House staff. Check with
  your RA\, GA\, or House Dean for more info.\n\n      \n\n      \nContact:
  \n  living@exchange.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160825T193000
DTEND;TZID=America/New_York:20160825T223000
LAST-MODIFIED:20160617T205633Z
SUMMARY:College House Meetings and Activities for Students Only
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-233000-2016-08-26-0
 23000/college-house-meetings-and-activities-students-only
END:VEVENT
BEGIN:VEVENT
UID:calendar.253.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T151836Z
DESCRIPTION:Dinner for Students Only \n\n      \n              \n\n\nMandat
 ory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n4:30 
 pm to 7:00 pm\n      \nEvent Location: \n  Various Locations\n\n          
     \nHost: \n  Penn Dining \n      \n      \nDescription: \n  \n\nKings C
 ourt English\, NCH\, and 1920 Commons dining halls. Kosher dinner availabl
 e at Falk Dining in Hillel. Houston Market for Transfer and Exchange stude
 nts.\n\n      \n\n      \nContact: \n  dining@upenn.edu for more informati
 on.
DTSTART;TZID=America/New_York:20160825T163000
DTEND;TZID=America/New_York:20160825T190000
LAST-MODIFIED:20160729T160420Z
SUMMARY:Dinner for Students Only
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-203000-2016-08-25-2
 30000/dinner-students-only
END:VEVENT
BEGIN:VEVENT
UID:calendar.251.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160614T144958Z
DESCRIPTION:President and Provost’s Family Welcome\n\n      \n             
  \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2
 016 - \n3:45 pm to 4:30 pm\n      \nEvent Location: \n  College Green \n\n
       \n      \nDescription: \n  \n\nJoin President Gutmann and Provost Pr
 ice for a welcome to Penn families at the steps of College Hall. For more 
 information\, and to register for New Parent and Family Orientation (NPFO)
 \, please visit this link.\n\n\nRain Location: Tent on Wynn Commons\n\n   
    \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more inform
 ation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T154500
DTEND;TZID=America/New_York:20160825T163000
LAST-MODIFIED:20160725T150701Z
LOCATION:College Hall\, Philadelphia\, PA 19104
SUMMARY:President and Provost’s Family Welcome
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-194500-2016-08-25-2
 03000/president-and-provost%E2%80%99s-family-welcome
END:VEVENT
BEGIN:VEVENT
UID:calendar.250.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T203132Z
DESCRIPTION:Introduction to Cultural and First Generation Resources at Penn
 \n\n      \n              \n\n\nMandatory: No\n      \n      \nDate & Time
 : \n  Thursday\, Aug 25 2016 - \n12:30 pm to 1:30 pm\n      \nEvent Locati
 on: \n  Terrace Room\, Cohen Hall\n\n              \nHost: \n  Greenfield 
 Intercultural Center\n      \n      \nDescription: \n  \n\nHear from retur
 ning students and resource center staff\, as they describe programs and se
 rvices they utilized and provide to support ethnic\, LGBT\, First Generati
 on\, and all students interested in intercultural programs. For more infor
 mation\, and to register for New Parent and Family Orientation (NPFO)\, pl
 ease visit this link.\n\n      \n\n      \nContact: \n  gic@dolphin.upenn.
 edu  for more information.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T123000
DTEND;TZID=America/New_York:20160825T133000
LAST-MODIFIED:20160725T150308Z
LOCATION:249 S 36th St\, Philadelphia\, PA 19104
SUMMARY:Introduction to Cultural and First Generation Resources at Penn
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-163000-2016-08-25-1
 73000/introduction-cultural-and-first-generation-resources-penn
END:VEVENT
BEGIN:VEVENT
UID:calendar.248.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T201612Z
DESCRIPTION:Library Showcase and Tours \n\n      \n              \n\n\nMand
 atory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n12:
 00 pm to 2:00 pm\n      \nEvent Location: \n  Van Pelt-Dietrich Library Ce
 nter \n\n      \n      \nDescription: \n  \n\nPenn’s libraries are hubs of
  research and learning and a home to innovative digital initiatives. Explo
 re the libraries’ resources and discover all the ways they can help studen
 ts succeed.  Guided tours led by library staff will be offered. (Advanced 
 registration required for tours.) Please visit here for more information. 
 \n\n      \n\n      \nContact: \n   library@pobox.upenn.edu for more infor
 mation.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T120000
DTEND;TZID=America/New_York:20160825T140000
LAST-MODIFIED:20160720T191500Z
LOCATION:3420 Walnut St\, Philadelphia\, PA 19104
SUMMARY:Library Showcase and Tours
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-160000-2016-08-25-1
 80000/library-showcase-and-tours
END:VEVENT
BEGIN:VEVENT
UID:calendar.247.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T194957Z
DESCRIPTION:Resources for Students with Disabilities\n\n      \n           
    \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25
  2016 - \n10:00 am to 11:00 am\n      \nEvent Location: \n  Conference Roo
 m\, Weingarten Learning Resource Center\n\n      \n      \nDescription: \n
   \n\nFind out about services\, resources\, and policies.\n\n      \n\n   
    \nContact: \n  lrcmail@pobox.upenn.edu for more information.\n\n      
 \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T100000
DTEND;TZID=America/New_York:20160825T110000
LAST-MODIFIED:20160630T143311Z
LOCATION:3702 Spruce Street
SUMMARY:Resources for Students with Disabilities
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-140000-2016-08-25-1
 50000/resources-students-disabilities
END:VEVENT
BEGIN:VEVENT
UID:calendar.246.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T194502Z
DESCRIPTION:Student Services Expo and Campus Express\n\n      \n           
    \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Thursday\, Aug 25
  2016 - \n9:00 am to 5:00 pm\n      \nEvent Location: \n  Houston Hall\n\n
       \n      \nDescription: \n  \n\nCampus Express Center \nPennCard: Pic
 k up your pre-made PennCard or have your card made on site.  Add cash to y
 our PennCard’s pre-paid debit feature PennCash\, which can be used for Uni
 versity facilities\, services\, events\, meals\, and more. \nRegister your
  bicycle or laptop: with the Penn Police or pick up registration stickers 
 if you arranged for them in advance.  Bicycle and laptop locks will be ava
 ilable for purchase. \nPenn Dining: Pick up service information and dining
  schedules\; meet with representatives to discuss flexible and varied dini
 ng options.\nPenn Transit Services: Get information on the transportation 
 services available at Penn\, including shuttle services\, Penn Buses (East
  & West)\, and accessible transit. Pick up transit maps and talk with repr
 esentatives from SEPTA\, Philadelphia’s public transportation system.\nBan
 king Options: Meet with representatives from the Student Federal Credit Un
 ion and PNC Bank and set up your bank account.\nAmazon @Penn: Amazon @Penn
 \, located in 1920 Commons\, offers a secure and convenient place to pick 
 up your Amazon orders. Amazon Student and Prime members get free Same-Day 
 or One-Day pick up on a wide selection of items.\nPersonalShip: All studen
 ts now have access to the University’s new PersonalShip program which allo
 ws you to ship your express mail packages via UPS and DHL at Penn’s discou
 nted rates\, resulting in significant savings on shipping costs\nTechnolog
 y Assistance – Representatives from Information and Security\, College Hou
 se Computing\, and the Computer Connection will be on hand to answer your 
 technology questions\, help you sign up for the new Comcast cable service\
 , and offer the latest technology at educational discounts.\n\n\nLibrary: 
 Learn about Penn’s libraries.\n\n\nDivision of Public Safety: Register for
  UPennAlert and Penn Guardian\, and get safety information about living on
  and off-campus. Visit our website for updates\, safety tips\, and a varie
 ty of other safety resources.\n\n\nRecreation: Get information about the s
 ports clubs\, intramural sports\, instructional classes\, and special even
 ts.\n\n\nStudent Financial Services: Visit this site for all student finan
 cial matters\, including billing\, payment options\, financial aid\, and l
 oans.\n\n\nStudent Employment: Search for both work-study and non-work-stu
 dy jobs\, and find forms or other employment details.\n\n\nCampus Health a
 nd Student Health Service: Student Health Service is located on campus and
  committed to partnering with you to treat your illnesses and injuries\, p
 romote wellness\, and provide you with health education and information. A
 ll full time students are eligible to access health services. Campus Healt
 h is the public health division of SHS and offers a wide array of health e
 ducation and disease prevention programs. For more details visit here.\n\n
 \nOffice of Government & Community Affairs: Register to vote and learn mor
 e about how to get civically engaged on campus.\n\n\nIn addition\, represe
 ntatives from the Penn Bookstore\, PennKey\, and Computing Resource Center
  will be present to answer any questions.\n\n\n \n\n      \n\n      \nCont
 act: \n  provost-nso-ai@pobox.upenn.edu for more information.\n\n      \n
 \n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160825T090000
DTEND;TZID=America/New_York:20160825T170000
LAST-MODIFIED:20160804T194145Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Student Services Expo and Campus Express
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-130000-2016-08-25-2
 10000/student-services-expo-and-campus-express
END:VEVENT
BEGIN:VEVENT
UID:calendar.245.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T194204Z
DESCRIPTION:NSO Hospitality Booths\n\n      \n              \n\n\nMandatory
 : No\n      \n      \nDate & Time: \n  Thursday\, Aug 25 2016 - \n9:00 am 
 to 4:30 pm\n      \nEvent Location: \n  34th & Walnut\; 37th & Locust\; Up
 per & Lower Quad\n\n      \n      \nDescription: \n  \n\nStaff available t
 o answer all of your questions.\n\n      \n\n      \nContact: \n  provost-
 nso-ai@pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView lar
 ger map
DTSTART;TZID=America/New_York:20160825T090000
DTEND;TZID=America/New_York:20160825T163000
LAST-MODIFIED:20160720T185826Z
LOCATION:Locust Walk & S 37th St\, Philadelphia\, PA 19104
SUMMARY:NSO Hospitality Booths
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-25-130000-2016-08-25-2
 03000/nso-hospitality-booths
END:VEVENT
BEGIN:VEVENT
UID:calendar.244.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T192936Z
DESCRIPTION:Dinner On Your Own\n\n      \n              \n\n\nMandatory: No
 \n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - 5:00 pm\n    
   \nEvent Location: \n  Various Locations\n\n      \n      \nDescription: 
 \n  \n\nExplore the various restaurants in Philadelphia. For a complete li
 st of local vendors offering specials\, visit the info desk in Houston Hal
 l or www.nso.upenn.edu. \n\n      \n\n      \nContact: \n  provost-nso-ai@
 pobox.upenn.edu for more information.
DTSTART;TZID=America/New_York:20160824T170000
DTEND;TZID=America/New_York:20160824T170000
LAST-MODIFIED:20160729T160353Z
SUMMARY:Dinner On Your Own
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-210000/dinner-your-
 own
END:VEVENT
BEGIN:VEVENT
UID:calendar.243.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T184308Z
DESCRIPTION:Student Services Expo and Campus Express\n\n      \n           
    \n\n\nMandatory: No\n      \n      \nDate & Time: \n  Wednesday\, Aug 2
 4 2016 - \n9:00 am to 5:00 pm\n      \nEvent Location: \n  Houston Hall\n
 \n      \n      \nDescription: \n  \n\nCampus Express Center \nPennCard: P
 ick up your pre-made PennCard or have your card made on site.  Add cash to
  your PennCard’s pre-paid debit feature PennCash\, which can be used for U
 niversity facilities\, services\, events\, meals\, and more. \nRegister yo
 ur bicycle or laptop: with the Penn Police or pick up registration sticker
 s if you arranged for them in advance.  Bicycle and laptop locks will be a
 vailable for purchase. \nPenn Dining: Pick up service information and dini
 ng schedules\; meet with representatives to discuss flexible and varied di
 ning options.\nPenn Transit Services: Get information on the transportatio
 n services available at Penn\, including shuttle services\, Penn Buses (Ea
 st & West)\, and accessible transit. Pick up transit maps and talk with re
 presentatives from SEPTA\, Philadelphia’s public transportation system.\nB
 anking Options: Meet with representatives from the Student Federal Credit 
 Union and PNC Bank and set up your bank account.\nAmazon @Penn: Amazon @Pe
 nn\, located in 1920 Commons\, offers a secure and convenient place to pic
 k up your Amazon orders. Amazon Student and Prime members get free Same-Da
 y or One-Day pick up on a wide selection of items.\nPersonalShip: All stud
 ents now have access to the University’s new PersonalShip program which al
 lows you to ship your express mail packages via UPS and DHL at Penn’s disc
 ounted rates\, resulting in significant savings on shipping costs\nTechnol
 ogy Assistance – Representatives from Information and Security\, College H
 ouse Computing\, and the Computer Connection will be on hand to answer you
 r technology questions\, help you sign up for the new Comcast cable servic
 e\, and offer the latest technology at educational discounts.\n\n\nLibrary
 : Learn about Penn’s libraries.\n\n\nDivision of Public Safety: Register f
 or UPennAlert and Penn Guardian\, and get safety information about living 
 on and off-campus. Visit our website for updates\, safety tips\, and a var
 iety of other safety resources.\n\n\nRecreation: Get information about the
  sports clubs\, intramural sports\, instructional classes\, and special ev
 ents.\n\n\nStudent Financial Services: Visit this site for all student fin
 ancial matters\, including billing\, payment options\, financial aid\, and
  loans.\n\n\nStudent Employment: Search for both work-study and non-work-s
 tudy jobs\, and find forms or other employment details.\n\n\nCampus Health
  and Student Health Service: Student Health Service is located on campus a
 nd committed to partnering with you to treat your illnesses and injuries\,
  promote wellness\, and provide you with health education and information.
  All full time students are eligible to access health services. Campus Hea
 lth is the public health division of SHS and offers a wide array of health
  education and disease prevention programs. For more details visit here.\n
 \n\nOffice of Government & Community Affairs: Register to vote and learn m
 ore about how to get civically engaged on campus.\n\n\nIn addition\, repre
 sentatives from the Penn Bookstore\, PennKey\, and Computing Resource Cent
 er will be present to answer any questions.\n\n\n \n\n\n \n\n\n \n\n      
 \n\n      \nContact: \n  provost-nso-ai@pobox.upenn.edu for more informati
 on.\n\n      \n\n  \n\n\nView larger map
DTSTART;TZID=America/New_York:20160824T090000
DTEND;TZID=America/New_York:20160824T170000
LAST-MODIFIED:20160804T194203Z
LOCATION:3417 Spruce St\, Philadelphia\, PA 19104
SUMMARY:Student Services Expo and Campus Express
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-130000-2016-08-24-2
 10000/student-services-expo-and-campus-express
END:VEVENT
BEGIN:VEVENT
UID:calendar.242.field_event_date.0@www.nso.upenn.edu
DTSTAMP:20160806T232433Z
CREATED:20160613T183718Z
DESCRIPTION:NSO Hospitality Booths \n\n      \n              \n\n\nMandator
 y: No\n      \n      \nDate & Time: \n  Wednesday\, Aug 24 2016 - \n9:00 a
 m to 4:30 pm\n      \nEvent Location: \n  34th & Walnut\; 37th & Locust\; 
 Upper & Lower Quad\n\n      \n      \nDescription: \n  \n\nStaff available
  to answer all of your questions.\n\n      \n\n      \nContact: \n  provos
 t-nso-ai@pobox.upenn.edu for more information.\n\n      \n\n  \n\n\nView l
 arger map
DTSTART;TZID=America/New_York:20160824T090000
DTEND;TZID=America/New_York:20160824T163000
LAST-MODIFIED:20160720T185243Z
LOCATION:Locust Walk & S 37th St\, Philadelphia\, PA 19104
SUMMARY:NSO Hospitality Booths
URL;TYPE=URI:https://www.nso.upenn.edu/event/2016-08-24-130000-2016-08-24-2
 03000/nso-hospitality-booths
END:VEVENT
END:VCALENDAR"""

def get_ical():
    return FILE
